<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

use MSP\DataType\ModelType as PostType;
$sm = MSP\WPObjects\Service\Manager::getInstance();

return array(
    
    array(
        'id' => PostType::MATCH,
        'model_class_name' => '\MSP\Model\Match',
        'qualifiers' => array(
            PostType::GAME,
            PostType::PLAYER,
            PostType::TEAM,
            PostType::REFEREE,
            PostType::CHAMPIONSHIP,
            PostType::BROADCAST,
            PostType::VENUE,
            PostType::MATCH_WEATHER_TYPE
        ),
        'register_metas' => array(
            '_player_data_.*',
            '_organisation_data_.*',
            '_date_start',
            '_date_end',
            '_team_winner_id',
            '_weather_degrees',
            '_weather_description',
            '_live_update',
            '_live_update_time',
            '_time_status',
            '_page_cover_image_id',
            '_match_status',
            '_lol_id', // League of Legends system match id
            '_lol_data', // League of Legends system match all data
            '_parcipient_*'
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxMatchGameSelector'),
            $sm->get('MetaBoxMatchSelectTeam'),
            $sm->get('MetaBoxMatchTeamStatistic'),
            $sm->get('MetaBoxMatchPlayerStatistic'),
            $sm->get('MetaBoxMatchConfiguration'),
            $sm->get('MetaBoxMatchSettings'),
            $sm->get('MetaBoxPageLiveUpdate'),
            $sm->get('MetaBoxMatchBG'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'factory_service_name' => 'MatchFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Matches', 'msp'),
                'singular_name' => __('Match', 'msp'),
                'add_new' => __('Add New match', 'msp'),
                'add_new_item' => __('Add New match', 'msp'),
                'edit_item' => __('Edit match', 'msp'),
                'new_item' => __('New match', 'msp'),
                'all_items' => __('All matches', 'msp'),
                'view_item' => __('View match', 'msp'),
                'search_items' => __('Search match', 'msp'),
                'not_found' => __('No matches found', 'msp'),
                'not_found_in_trash' => __('No matches found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Matches', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Matches.png',
            'supports' => array('title', 'editor', 'thumbnail', 'excerpt', 'revisions'),
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::BROADCAST,
        'model_class_name' => '\MSP\Model\Broadcast',
        'qualifiers' => array(
            PostType::GAME,
            PostType::COMMENTATOR,
            PostType::COUNTRY,
            PostType::TEAM,
            PostType::PLAYER,
            PostType::CHAMPIONSHIP,
            PostType::BROADCAST_STATUS
        ),
        'register_metas' => array(
            '_broadcast_bg',
            '_steam_twitch_id',
            '_twitch_api_enable',
            '_viewers_count',
            '_broadcasts_statu_id',
            '_page_cover_image_id',
            '_last_live_date',
            '_last_screenshot_url',
        ),
        'factory_service_name' => 'BroadcastFactory',
        'MetaBoxes' => array(
            $sm->get('MetaBoxBroadcastSettings'),
            $sm->get('MetaBoxBroadcastInformation'),
            $sm->get('MetaBoxBroadcastLogo'),
            $sm->get('MetaBoxBroadcastBg'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'config' => array (
            'labels' => array(
                'name' => __('Broadcasts', 'msp'),
                'singular_name' => __('Broadcast', 'msp'),
                'add_new' => __('Add new broadcast', 'msp'),
                'add_new_item' => __('Add new broadcast', 'msp'),
                'edit_item' => __('Edit broadcast', 'msp'),
                'new_item' => __('New broadcast', 'msp'),
                'all_items' => __('All broadcasts', 'msp'),
                'view_item' => __('View broadcast', 'msp'),
                'search_items' => __('Search broadcasts', 'msp'),
                'not_found' => __('Broadcasts not found', 'msp'),
                'not_found_in_trash' => __('broadcasts not found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Broadcasts', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Broadcasts.png',
            'supports' => array('thumbnail', 'editor', 'title'),
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::CHAMPIONSHIP,
        'model_class_name' => '\MSP\Model\Championship',
        'qualifiers' => array(
            PostType::GAME,
            PostType::TEAM
        ),
        'register_metas' => array(
            '_attrs',
            '_organisation_winners',
            '_date_start',
            '_date_end',
            '_page_cover_image_id',
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxChampionshipLogo'),
            $sm->get('MetaBoxChampionshipInformation'),
            $sm->get('AttrsMetaBox'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'factory_service_name' => 'ChampionshipFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Championships', 'msp'),
                'singular_name' => __('Championship', 'msp'),
                'add_new' => __('Add New championship', 'msp'),
                'add_new_item' => __('Add New championship', 'msp'),
                'edit_item' => __('Edit championship', 'msp'),
                'new_item' => __('New championship', 'msp'),
                'all_items' => __('All championships', 'msp'),
                'view_item' => __('View championship', 'msp'),
                'search_items' => __('Search championships', 'msp'),
                'not_found' => __('No championships found', 'msp'),
                'not_found_in_trash' => __('No championships found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Championships', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Championships.png',
            'supports' => array('thumbnail', 'title', 'editor', 'excerpt'),
            'menu_position' => 25
        )
    ),
    
    PostType::COMMENTATOR => array(
        'id' => PostType::COMMENTATOR,
        'model_class_name' => '\MSP\Model\Commentator',
        'qualifiers' => array(
            PostType::COUNTRY
        ),
        'register_metas' => array(
            '_socials'
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxCommentatorPhoto'),
            $sm->get('MetaBoxCommentatorInformation'),
            $sm->get('SocialsMetabox')
        ),
        'factory_service_name' => 'CommentatorFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Commentators', 'msp'),
                'singular_name' => __('Commentator', 'msp'),
                'add_new' => __('Add New commentator', 'msp'),
                'add_new_item' => __('Add New commentator', 'msp'),
                'edit_item' => __('Edit commentator', 'msp'),
                'new_item' => __('New commentator', 'msp'),
                'all_items' => __('All commentators', 'msp'),
                'view_item' => __('View commentator', 'msp'),
                'search_items' => __('Search commentators', 'msp'),
                'not_found' => __('No commentators found', 'msp'),
                'not_found_in_trash' => __('No commentators found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Commentators', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Commentators.png',
            'supports' => array('thumbnail', 'editor', 'title', 'excerpt'),
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::MATCH_EVENT,
        'model_class_name' => '\MSP\Model\MatchEvent',
        'qualifiers' => array(
            PostType::MATCH,
            PostType::PLAYER,
            PostType::MATCH_EVENT_TYPE
        ),
        'qualifiers_attr_names' => array (
            PostType::MATCH_EVENT_TYPE => '_event_type_id',
            PostType::MATCH => '_match_id'
        ),
        'register_metas' => array(
            '_match_time'
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxMatchEventInfo')
        ),
        'factory_service_name' => 'MatchEventFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Match events', 'msp'),
                'singular_name' => __('Match event', 'msp'),
                'add_new' => __('Add new match event', 'msp'),
                'add_new_item' => __('Add new match event', 'msp'),
                'edit_item' => __('Edit match event', 'msp'),
                'new_item' => __('New match event', 'msp'),
                'all_items' => __('All events', 'msp'),
                'view_item' => __('View event', 'msp'),
                'search_items' => __('Search events', 'msp'),
                'not_found' => __('No events found', 'msp'),
                'not_found_in_trash' => __('No events found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Match events', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Match events.png',
            'supports' => array('editor'),
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::TEAM,
        'model_class_name' => '\MSP\Model\Team',
        'qualifiers' => array(
            PostType::GAME,
            PostType::COUNTRY
        ),
        'context_methods_reading' => array (
            PostType::PLAYER => function (\MSP\Model\Player $Player) {
                return $Player->getTeamsHistoryIds();
            }
        ),
        'register_metas' => array(
            '_attrs',
            '_msp__organisation_photo',
            '_organisation_stats',
            '_organisation_stat_cache_.*',
            '_page_cover_image_id',
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxTeamLogo'),
            $sm->get('MetaBoxTeamInformation'),
            $sm->get('AttrsMetaBox'),
            $sm->get('MetaBoxTeamPhoto'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'factory_service_name' => 'TeamFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Teams', 'msp'),
                'singular_name' => __('Team', 'msp'),
                'add_new' => __('Add new team', 'msp'),
                'add_new_item' => __('Add new team', 'msp'),
                'edit_item' => __('Edit team', 'msp'),
                'new_item' => __('New team', 'msp'),
                'all_items' => __('All teams', 'msp'),
                'view_item' => __('View team', 'msp'),
                'search_items' => __('Search teams', 'msp'),
                'not_found' => __('Teams not found', 'msp'),
                'not_found_in_trash' => __('Teams not found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Teams', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Organisations.png',
            'supports' => array('editor', 'title', 'thumbnail'),
            'menu_position' => 25,
        )
    ),
    
    array(
        'id' => PostType::PLAYER,
        'model_class_name' => '\MSP\Model\Player',
        'qualifiers' => array(
            PostType::TEAM,
            PostType::PLAYER_POSITION,
            PostType::PLAYER_ROLE,
            PostType::GAME,
            PostType::PLAYER_TEAM_ACTIVITY,
            PostType::PLAYER_ROLE,
            PostType::PLAYER_HERO,
            PostType::COUNTRY,
            PostType::PLAYER_ITEM
        ),
        'qualifiers_attr_names' => array (
            PostType::PLAYER_TEAM_ACTIVITY => '_player_team_activity_id',
            PostType::PLAYER_ROLE => '_player_role_id',
            PostType::PLAYER_HERO => '_player_hero_id',
            PostType::PLAYER_POSITION => '_player_position_id',
            PostType::PLAYER_ITEM => '_player_items'
        ),
        'register_metas' => array(
            '_player_nickname',
            '_player_city',
            '_player_height',
            '_player_weight',
            '_player_full_name',
            '_player_number',
            '_player_capitan',
            '_player_birthday',
            '_socials',
            '_player_stat_cache_.*',
            '_player_stats',
            '_attrs',
            '_page_cover_image_id',
        ),
        'factory_service_name' => 'PlayerFactory',
        'MetaBoxes' => array(
            $sm->get('MetaBoxGameSelector'),
            $sm->get('MetaBoxPlayerPhoto'),
            $sm->get('MetaBoxPlayerInformation'),
            $sm->get('MetaBoxPlayerSpecifications'),
            $sm->get('SocialsMetabox'),
            $sm->get('AttrsMetaBox'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'config' => array (
            'labels' => array(
                'name' => __('Players', 'msp'),
                'singular_name' => __('Player', 'msp'),
                'add_new' => __('Add New player', 'msp'),
                'add_new_item' => __('Add New player', 'msp'),
                'edit_item' => __('Edit player', 'msp'),
                'new_item' => __('New player', 'msp'),
                'all_items' => __('All players', 'msp'),
                'view_item' => __('View player', 'msp'),
                'search_items' => __('Search players', 'msp'),
                'not_found' => __('No players found', 'msp'),
                'not_found_in_trash' => __('No players found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Players', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Players.png',
            'supports' => array('thumbnail', 'editor', 'title'),
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::REFEREE,
        'model_class_name' => '\MSP\Model\Referee',
        'qualifiers' => array(
            PostType::GAME,
            PostType::COUNTRY
        ),
        'register_metas' => array(
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxRefereePhoto'),
            $sm->get('MetaBoxRefereeInformation'),
        ),
        'factory_service_name' => 'RefereeFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Referees', 'msp'),
                'singular_name' => __('Referee', 'msp'),
                'add_new' => __('Add new referee', 'msp'),
                'add_new_item' => __('Add new referee', 'msp'),
                'edit_item' => __('Edit referee', 'msp'),
                'new_item' => __('New referee', 'msp'),
                'all_items' => __('All referees', 'msp'),
                'view_item' => __('View referee', 'msp'),
                'search_items' => __('Search referees', 'msp'),
                'not_found' => __('Referees not found', 'msp'),
                'not_found_in_trash' => __('Referees not found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Referees', 'msp'),
            ),
            'public' => true,
            'supports' => array('thumbnail', 'editor', 'title'),
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Referee.png',
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::STANDING,
        'model_class_name' => '\MSP\Model\Standing',
        'qualifiers' => array(
            PostType::CHAMPIONSHIP
        ),
        'register_metas' => array(
            '_stage_count',
            '_score_type',
            '_stage_.*',
            '_stage_count',
            '_page_cover_image_id',
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxStandingInformation'),
            $sm->get('MetaBoxStandingEditing'),
            $sm->get('MetaBoxPageCoverImage'),
        ),
        'factory_service_name' => 'StandingFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Standings', 'msp'),
                'singular_name' => __('Standing', 'msp'),
                'add_new' => __('Add New standing', 'msp'),
                'add_new_item' => __('Add New standing', 'msp'),
                'edit_item' => __('Edit standing', 'msp'),
                'new_item' => __('New standing', 'msp'),
                'all_items' => __('All standings', 'msp'),
                'view_item' => __('View standing', 'msp'),
                'search_items' => __('Search standings', 'msp'),
                'not_found' => __('No standings found', 'msp'),
                'not_found_in_trash' => __('No standings found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Standings', 'msp'),
            ),
            'public' => true,
            'supports' => array('title', 'editor'),
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Standings.png',
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::TRAINER,
        'model_class_name' => '\MSP\Model\Trainer',
        'qualifiers' => array(
            PostType::TEAM,
            PostType::COUNTRY
        ),
        'register_metas' => array(
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxTrainerPhoto'),
            $sm->get('MetaBoxTrainerInformation')
        ),
        'factory_service_name' => 'TrainerFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Trainers', 'msp'),
                'singular_name' => __('Trainer', 'msp'),
                'add_new' => __('Add New trainer', 'msp'),
                'add_new_item' => __('Add New trainer', 'msp'),
                'edit_item' => __('Edit trainer', 'msp'),
                'new_item' => __('New trainer', 'msp'),
                'all_items' => __('All trainers', 'msp'),
                'view_item' => __('View trainer', 'msp'),
                'search_items' => __('Search trainers', 'msp'),
                'not_found' => __('No trainers found', 'msp'),
                'not_found_in_trash' => __('No trainers found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Trainers', 'msp'),
            ),
            'public' => true,
            'supports' => array('thumbnail', 'editor', 'title'),
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Trainers.png',
            'menu_position' => 25
        )
    ),
    
    array(
        'id' => PostType::TROPHI,
        'model_class_name' => '\MSP\Model\Trophy',
        'qualifiers' => array(
            PostType::TEAM,
            PostType::PLAYER
        ),
        'register_metas' => array(
            '_date'
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxTrophyPhoto'),
            $sm->get('MetaBoxTrophyInformation')
        ),
        'factory_service_name' => 'TrophyFactory',
        'config' => array (
            'labels' => array(
                'name' => __('Trophies', 'msp'),
                'singular_name' => __('Trophy', 'msp'),
                'add_new' => __('Add New trophy', 'msp'),
                'add_new_item' => __('Add New trophy', 'msp'),
                'edit_item' => __('Edit trophy', 'msp'),
                'new_item' => __('New trophy', 'msp'),
                'all_items' => __('All trophies', 'msp'),
                'view_item' => __('View trophy', 'msp'),
                'search_items' => __('Search trophies', 'msp'),
                'not_found' => __('No trophies found', 'msp'),
                'not_found_in_trash' => __('No trophies found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Trophies', 'msp'),
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Championships.png',
            'supports' => array('thumbnail', 'title', 'editor', 'excerpt'),
            'menu_position' => 30
        )
    ),
    
    array(
        'id' => PostType::VENUE,
        'model_class_name' => '\MSP\Model\Venue',
        'factory_service_name' => 'VenueFactory',
        'MetaBoxes' => array(
            $sm->get('MetaBoxVenuePhoto')
        ),
        'config' => array (
            'labels' => array(
              'name' => __('Venue', 'msp'),
                'singular_name' => __('Venue', 'msp'),
                'add_new' => __('Add new venue', 'msp'),
                'add_new_item' => __('Add new venue', 'msp'),
                'edit_item' => __('Edit venue', 'msp'),
                'new_item' => __('New venue', 'msp'),
                'all_items' => __('All venues', 'msp'),
                'view_item' => __('View venue', 'msp'),
                'search_items' => __('Search venues', 'msp'),
                'not_found' => __('Venues not found', 'msp'),
                'not_found_in_trash' => __('Venues not found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Venues', 'msp'),  
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Venue.png',
            'supports' => array('editor', 'thumbnail', 'title'),
            'menu_position' => 25
        )
    ),
                
    array(
        'id' => PostType::SPONSOR,
        'model_class_name' => '\MSP\Model\Sponsor',
        'factory_service_name' => 'SponsorFactory',
        'qualifiers' => array(
            PostType::SPONSOR_TYPE,
        ),
        'register_metas' => array(
            '_main_website_link',
            '_socials',
            '_attrs'
        ),
        'MetaBoxes' => array(
            $sm->get('MetaBoxSponsorLogo'),
            $sm->get('MetaBoxSponsorSettings'),
            $sm->get('SocialsMetabox'),
            $sm->get('AttrsMetaBox'),
        ),
        'config' => array (
            'labels' => array(
              'name' => __('Sponsors', 'msp'),
                'singular_name' => __('Sponsor', 'msp'),
                'add_new' => __('Add new sponsor', 'msp'),
                'add_new_item' => __('Add new sponsor', 'msp'),
                'edit_item' => __('Edit sponsor', 'msp'),
                'new_item' => __('New sponsor', 'msp'),
                'all_items' => __('All sponsors', 'msp'),
                'view_item' => __('View sponsor', 'msp'),
                'search_items' => __('Search sponsors', 'msp'),
                'not_found' => __('Sponsors not found', 'msp'),
                'not_found_in_trash' => __('Sponsors not found in Trash', 'msp'),
                'parent_item_colon' => '',
                'menu_name' => __('Sponsors', 'msp'),  
            ),
            'public' => true,
            'menu_icon' => MSP_PATH_URL . '/images/post-types-menu-icons/icons_Sponsors.png',
            'supports' => array('editor', 'thumbnail', 'title'),
            'menu_position' => 25
        )
    ),
);

