<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Cron;

class TwitchBroadcasts implements
    \MSP\WPObjects\EventManager\ListenerInterface,
    \MSP\WPObjects\Service\ManagerInterface
{
    /**
     * Global service manager
     * 
     * @var \MSP\WPObjects\Service\Manager
     */
    protected $ServiceManager = null;
    
    protected $interval = 60;
    
    protected $task_key = 'twitch_broadcasts';
    
    protected $task_name = 'Twitch broadcasts';
    
    public function attach()
    {
        \add_action('init', array($this, 'initCron'));
        \add_filter('cron_schedules', array($this, 'getCronSchedule'));
        \add_action('twitch_broadcasts_processing', array($this, 'process'));
    }
    
    public function detach()
    {
        \remove_action('init', array($this, 'initCron'));
        \remove_filter('cron_schedules', array($this, 'getCronSchedule'));
        \remove_action('twitch_broadcasts_processing', array($this, 'process'));
    }
    
    public function process()
    {
        $APITwitch = $this->getServiceManager()->get('APITwitch');
        $BroadcastFactory = $this->getServiceManager()->get('BroadcastFactory');
        $Streams = $BroadcastFactory->getTwitchStreams();
        
        /* @var $Stream \MSP\Model\Broadcast */
        foreach ($Streams as $Stream) {
            $twitch_id = $Stream->getTwitchId();
            $data = $APITwitch->requestChannel($twitch_id);
            if (!isset($data['_total'])) {
                continue;
            }
            
            if (!$data['_total']) {
                $Stream->setStatusId(1);
                $Stream->setViewersCount(0);
                $Stream->setLastScreenshotUrl('');
            } else {
                $Stream->setStatusId(100);
                $stream_data = current($data['streams']);
                $previews = $stream_data['preview'];
                
                $Stream->setViewersCount((int)$stream_data['viewers']);
                $Stream->setLastLiveDate(\current_time('Y-m-d H:i:s'));
                $Stream->setLastScreenshotUrl(isset($previews['large']) ? $previews['large'] : '');
            }
            
            
            $Stream->saveMetas();
        }
    }
    
    public function initCron()
    {
        if ( !wp_next_scheduled( 'twitch_broadcasts_processing' ) ) { 
            \wp_schedule_event(time(), 'twitch_broadcasts_schedule', 'twitch_broadcasts_processing'); 
	}
    }
    
    public function getCronSchedule($schedules)
    {
        $schedules['twitch_broadcasts_schedule'] = array( 
            'interval' => $this->interval,
            'display' => 'Twitter broadcasts schedule' 
        );
        
	return $schedules;
    }
    
    public function setServiceManager(\MSP\WPObjects\Service\Manager $ServiceManager)
    {
        $this->ServiceManager = $ServiceManager;
        
        return $this;
    }
    
    /**
     * @return \MSP\WPObjects\Service\Manager
     * @throws \Exception
     */
    public function getServiceManager()
    {
        if (is_null($this->ServiceManager)) {
            throw new \Exception('Undefined service manager');
        }
        
        return $this->ServiceManager;
    }
}