<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Data;

use MSP\WPObjects\Data\Data as AbstractData;
use MSP\DataType\ModelType;

class Data extends AbstractData
{
    protected $wp_option_prefix = 'msp';
    
    public function getDataFilteredByGame(\MSP\WPObjects\Model\AbstractModelType $ModelType, $game_id)
    {
        $datas = $this->getDatas($ModelType->getStorage());
        $game_key = $ModelType->getQualifierAttrName(ModelType::GAME);
        $result = array();
        foreach ($datas as $data) {
            if (!isset($data[$game_key])) {
                $result[] = $data;
            } else if (is_array($data[$game_key]) && in_array($game_id, $data[$game_key])) {
                $result[] = $data;
            } else if ($data[$game_key] == $game_id) {
                $result[] = $data;
            }
        }

        return $result;
    }
    
    protected function filterBuildInData($datas, \MSP\WPObjects\Data\AbstractStorage $Storage)
    {
        $datas = parent::filterBuildInData($datas, $Storage);
        if (!in_array($Storage->getId(), array(
            ModelType::TEAM_STATISTIC_TYPE,
            ModelType::PLAYER_STATISTIC_TYPE,
            ModelType::GAME,
            ModelType::MATCH_EVENT_TYPE,
            ModelType::MATCH_WEATHER_TYPE,
        ))) {
            return $datas;
        }
        
        $DataType = \MSP\WPObjects\Service\Manager::getInstance()->get('DataTypeFactory')->get($Storage->getId());
        if (!$DataType) {
            return $datas;
        }
        
        if (isset($DataType->has_images) && $DataType->has_images) {
            $id_atts = $DataType->getIdAttrName();
            foreach ($datas as $key => $data) {
                $data['img_url'] = $this->getDataTypeImageUrl($DataType->getId(), $data[$id_atts]);
                $data['img_url_mini'] = $this->getDataTypeImageUrl($DataType->getId(), $data[$id_atts], 'mini');
                $datas[$key] = $data;
            }
        }
        
        $GameFactory = \MSP\WPObjects\Service\Manager::getInstance()->get('GameFactory');
        if ($DataType->getId() == ModelType::TEAM_STATISTIC_TYPE || 
            $DataType->getId() == ModelType::PLAYER_STATISTIC_TYPE) {
            $attr = $DataType->getQualifierAttrName(ModelType::GAME);
            $all_games_ids = $GameFactory->query()->getResultIds();
            foreach ($datas as $key => $data) {
                if (isset($data[$attr]) && $data[$attr] === '*') {
                    $datas[$key][$attr] = $all_games_ids;
                }
            }
            
        }
        
        return $datas;
    }
    
    public function getDataTypeImageUrl($data_type_id, $data_id, $size = '')
    {
        if ($size !== '') {
            $size = $size . '/';
        }

        if (file_exists(MSP_PATH . '/images/'. $data_type_id .'/' . $size . $data_id . '.png')) {
            return MSP_PATH_URL . '/images/'. $data_type_id .'/'. $size . $data_id . '.png';
        }

        if (file_exists(MSP_PATH . '/images/' . $size .  $data_type_id .'/default.png')) {
            return MSP_PATH_URL . '/images/' . $size . $data_type_id .'/default.png';
        }

        return null;
    }
    
    public function getDataTypeWpOptionKeyDisables($datas_type_id)
    {
        if ($datas_type_id != "games") {
            return $this->wp_option_prefix . '_data_' . $datas_type_id . '_disables';
        }

        return 'team-settings-games';
    }
}