<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Factory;

class Match extends AbstractFactory
{
    protected function buildDefaultOrgering()
    {
        $this->query['meta_key'] = '_date_start';
        $this->query['orderby'] = 'meta_value';
        $this->query['order'] = "DESC";
    }
    
    protected function buildSpecialMetaQuery()
    {
        if (isset($this->filters['_date_start']) && $this->filters['_date_start']) {
            $this->meta_query[] = array(
                'key' => '_date_start',
                'value' => $this->filters['_date_start'],
                'compare' => isset($this->filters['_date_start_compare']) ? $this->filters['_date_start_compare'] : '<'
            );
        }
        
        if (isset($this->filters['broadcasts_exists'])) {
            $this->meta_query[] = array(
                'key' => '_broadcast_id',
                'compare' => 'EXISTS'
            );
        }
        
        if (isset($this->filters['_match_status']) ) {
            $this->buildMatchStatusMetaQuery();
        }
    }
    
    protected function buildMatchStatusMetaQuery()
    {
        $status = explode(',', $this->filters['_match_status']);
        $status_querys = array('relation' => 'OR');

        if (in_array('0', $status)) {

            $status_querys[] = array(
                'key' => '_date_start',
                'value' => date('Y-m-d H:i:s'),
                'compare' => '>'
            );
        }

        if (in_array('1', $status)) {

            $status_querys[] = array(
                'relation' => 'AND',
                array(
                    'key' => '_date_start',
                    'value' => date('Y-m-d H:i:s'),
                    'compare' => '<'
                ),
                array(
                    'key' => '_team_winner_id',
                    'compare' => 'NOT EXISTS'
                )
            );

            /*
            $status_querys[] = array(
                'key' => '_date_start',
                'value' => date('Y-m-d H:i:s'),
                'compare' => '<'
            );
            $status_querys[] = array(
                'key' => '_team_winner_id',
                'compare' => 'NOT EXISTS'
            );*/
        }

        if (in_array('2', $status)) {

            $status_querys[] = array(
                'key' => '_team_winner_id',
                //'value' => 0,
                'compare' => 'EXISTS',
                //'type' => 'numeric'
            );
        }

        if (in_array('3', $status)) {

            $status_querys[] = array(
                'key' => '_time_status',
                'value' => 3,
            );
        }

        if (in_array('4', $status)) {

            $status_querys[] = array(
                'key' => '_time_status',
                'value' => 4,
            );
        }

        if (in_array('5', $status)) {

            $status_querys[] = array(
                'key' => '_time_status',
                'value' => 5,
            );
        }

        $this->meta_query[] = $status_querys;
    }
    
    /**
     * Return array with compatible elements for autocompele selector in Visual Composer Addons.
     * @return array
     */
    public function getForVCAutocompele()
    {
        $result = array();
        foreach ($this->getResult() as $Match) {
            $Game = $Match->getGame();

            $result[] = array(
                'label' => $Match->getName(),
                'value' => $Match->getId(),
                'group' => $Game ? $Game->getName() : esc_html__('Other', 'msp')
            );
        }

        return $result;
    }
    
    public function getSpecialQueryParamsForVCAddons()
    {
        return array(
            array(
                "type" => "checkbox",
                "heading" => __( "Matches with statuses", 'msp' ),
                "param_name" => "_match_status",
                "group" => __( "Matches query", 'msp' ),
                "value" => team_get_match_statuses_checkbox()
            ),
        );
    }
}