<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\LayoutsBuilder\Depth;

/**
 * @since 4.1.3
 */
class Team extends \PageComponents\Depth\AbstractDepth
{
    protected $attr_name = 'team_id';
    protected $factory_service = 'TeamFactory';
    protected $mode_type_service = 'ModelTypeTeam';
    protected $selector_name = 'Rule fo team';
    
    public function determinateLayout(\PageComponents\Model\Layout $Layout)
    {
        if (!$Layout->getRulePostType() || !$Layout->isSinglePost() || !$Layout->getParams($this->attr_name) ||
            !$Layout->getParams('game_id') ) {
            return false;
        }
        
        $SM = \MSP\WPObjects\Service\Manager::getInstance();
        $game_id = $Layout->getParams($this->attr_name);
        $Game = $SM->get($this->factory_service)->get($game_id);
        if ($Game) {
            return true;
        } 
        
        return false;
    }
    
    public function getLayoutSettings(\PageComponents\Model\Layout $Layout)
    {
        if (!$Layout->getRulePostType() || $Layout->getRulePostId() !== 'any' || !$Layout->getParams('game_id')) {
            return array();
        }
        
        
        $SM = \MSP\WPObjects\Service\Manager::getInstance();
        $post_type_id = $Layout->getRulePostType();
        $ModelType = $SM->get('PostTypeFactory')->get($post_type_id);
        $GameModelType = $SM->get($this->mode_type_service);
        if (!$ModelType || !$ModelType->hasQualifier($GameModelType->getId())) {
            return array();
        }
        
        $Games = $SM->get($this->factory_service)->query()->getResult();
        $options = array();
        foreach ($Games as $Game) {
            $options[] = array(
                'id' => $Game->getId(),
                'name' => $Game->getName()
            );
        }
        
        return array(
            array(
                'type' => 'select',
                'name' => $this->attr_name,
                'label' => $this->selector_name,
                'selected' => $Layout->getParams($this->attr_name),
                'options' => $options
            )
        );
    }
    
    public function readWordpressContext(\PageComponents\Model\WordpressContext $Context)
    {
        $SM = \MSP\WPObjects\Service\Manager::getInstance();
        $post_type_id = $Context->getPostType();
        $ModelType = $SM->get('PostTypeFactory')->get($post_type_id);
        if (!$ModelType) {
            return array();
        }
        
        $GameModelType = $SM->get($this->mode_type_service);
        
        $game_meta_attr = $ModelType->getQualifierAttrName($GameModelType->getId());
        $game_id = get_post_meta($Context->getPostId(), $game_meta_attr, true);
        if (!$game_id) {
            return array();
        }
        
        return array(
            $this->attr_name => $game_id
        );
    }
    
    public function determinateLayoutName(\PageComponents\Model\Layout $Layout)
    {
        $PostType = \get_post_type_object( $Layout->getRulePostType() );
        
        $SM = \MSP\WPObjects\Service\Manager::getInstance();
        $game_id = $Layout->getParams($this->attr_name);
        $Game = $SM->get($this->factory_service)->get($game_id);
        if (!$Game) {
            return $game_id . ' ' . $PostType->labels->name;
        }
        
        return $Game->getName() . ' ' . $PostType->labels->name;
    }
    
    public function determinateLayoutId(\PageComponents\Model\Layout $Layout)
    {
        $game_id = $Layout->getParams($this->attr_name);
        $post_type = $Layout->getParams('post_type');
        return $this->getId() . '_' . $post_type . '_' . $game_id;
    }
    
    public function filterLayoutParams($params)
    {
        return array(
            'post_type' => $params['post_type'],
            'post_id' => 'any',
            'game_id' => $params['game_id'],
            $this->attr_name => $params[$this->attr_name]
        );
    }
}