<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\MetaBox;

use MSP\WPObjects\PostType\MetaBox;

abstract class AbstractMetaBox extends MetaBox
{
    public function __construct()
    {
    }
    
    /**
     * @var \WPObjects\Model\AbstractPostModel
     */
    protected $PostModel = null;
    
    /**
     * @return \WPObjects\Model\AbstractPostModel
     */
    protected function getPostModel()
    {
        if (is_null($this->PostModel) && $this->getPost()) {
            $PostType = $this->getPostType();
            $this->PostModel = $PostType->createModel($this->getPost());
        }
        
        return $this->PostModel;
    }
    
    /**
     * @return \WPObjects\PostType\PostType
     */
    protected function getPostType()
    {
        $Factory = $this->getServiceManager()->get('PostTypeFactory');
        return $Factory->get($this->getPost()->post_type);
    }
    
    public function getTemplatePath()
    {
        return MSP_PATH . 'includes/templates/meta-box/' . $this->getId()  . '.php';
    }
    
    public function enqueues()
    {
        $this->getAssetsManager()
             ->enqueueStyle('form')
             ->enqueueScript('selectors');
    }
    
    public function renderQualifierSelector($model_type_id, $lable, $vertical = true, $desctiption = "", $multibple = false, $qualifier = null, $array_result = false)
    {
        $Factory = $this->getServiceManager()->get('ModelTypeFactory');
        $ModelType = $Factory->get($model_type_id);
        $Game = $this->getGame();
        
        $options_filters = array();
        if ($Game && $ModelType->hasQualifier(\MSP\DataType\ModelType::GAME)) {
            $filter_name = $ModelType->getQualifierAttrName(\MSP\DataType\ModelType::GAME);
            $options_filters[$filter_name] = $Game->getId();
        }
        
        $Models = $ModelType->getFactory()->query($options_filters)->getResult();
        
        $options = array();
        foreach ($Models as $Model) {
            $options[] = array(
                'id' => $Model->getId(),
                'name' => $Model->getName(),
                'img' => $Model->getImgForSelect()
            );
        }
        
        $lable = $lable ? $lable : $ModelType->getName();
        $name = $qualifier === null ? $this->getPostType()->getQualifierAttrName($model_type_id) : $qualifier;
        $selected = $this->getPostModel()->getMeta($name);
        if (!is_array($selected)) {
            $selected = array($selected);
        }
        
        if ($ModelType instanceof \MSP\WPObjects\PostType\PostType) {
            $add_new_link = $ModelType->getAddNewLink();
            $add_new_text = $ModelType->getLabels('add_new_item');                     
        } else {
            $add_new_link = $this->getAddNewEntryLink();
            $add_new_text = __('Add new entry to') . ' ' . $ModelType->getName();
        }
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function renderCustomInput($meta_attr_name, $lable, $vertical = true, $desctiption = "", $type = 'text', $step = "", $invert_with = false, $balance_with = false)
    {
        $value = $this->getPostModel()->getMeta($meta_attr_name);
        include $this->getPartTemplatePath('custom-input');
    }
    
    public function renderCustomCheckbox($meta_attr_name, $lable, $vertical = true, $desctiption = "")
    {
        $meta_value = $this->getPostModel()->getMeta($meta_attr_name) ;
        $value = $meta_value ? true : false;
        
        include $this->getPartTemplatePath('checkbox');
    }
    
    public function renderDateTimeInput($meta_time_attr, $lable, $vertical = true, $desctiption = "")
    {
        $meta_value = $this->getPostModel()->getMeta($meta_time_attr);
        if (!strtotime($meta_value)) {
            include $this->getPartTemplatePath('datetime');
            return;
        }
        
        $Date = \date_create($meta_value);
        
        $date = $Date->format('Y-m-d');
        $hours = $Date->format('H');
        $minutes = $Date->format('i');
        
        include $this->getPartTemplatePath('datetime');
    }
    
    public function getAddNewEntryLink()
    {
        $DashboardPage = $this->getServiceManager()->get('DatabasePage');
        return $DashboardPage->getUrl();
    }
    
    public function getPartTemplatePath($name)
    {
        return MSP_PATH . 'includes/templates/meta-box/template-parts/' . $name  . '.php';
    }
    
    public function getGame()
    {
        $Model = $this->getPostModel();
        $ModelType = $Model->getModelType();
        if (!$ModelType->hasQualifier(\MSP\DataType\ModelType::GAME)) {
            return false;
        }
        
        return $Model->getRelative(\MSP\DataType\ModelType::GAME);
    }
}