<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\MetaBox;

class MatchConfiguration extends AbstractMetaBox
{
    public function __construct()
    {
        $this->setId('match-configuration');
        $this->setTitle('Match configuration');
        $this->setPosition('side');
        $this->setPriority('default');
    }
    
    public function processing(\MSP\WPObjects\Model\AbstractPostModel $Post, $data)
    {
        if (!isset($data['_date_start_date']) && !$data['_date_end_date']) {
            $data['_date_start'] = gmdate('Y-m-d H:i:s');
            return $data;
        }
        
        $data['_date_start'] = $data['_date_start_date'] . ' ' . $data['_date_start_hours'] . ':' . $data['_date_start_minutes'] . ':00';
        $data['_date_end'] = $data['_date_end_date'] . ' ' . $data['_date_end_hours'] . ':' . $data['_date_end_minutes'] . ':00';
        
        return $data;
    }
    
    public function getTeamWinnerSelect()
    {
        $Models = $this->getMatch()->getTeams();
        
        $options = array();
        foreach ($Models as $Model) {
            $options[] = array(
                'id' => $Model->getId(),
                'name' => $Model->getName(),
                'img' => $Model->getImgForSelect()
            );
        }
        
        $options[] = array(
            'id' => "draw",
            'name' => __('Draw', 'msp'),
            'img' => ''
        );
        
        $lable = __('Winner', 'msp');
        $name = '_team_winner_id';
        $selected = array($this->getMatch()->getTeamWinnerId());
        $vertical = true;
        $desctiption = "";
        $multibple = false;
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function renderMatchStatusSelector()
    {
        $lable = __('Match time', 'msp');
        $name = '_time_status';
        $selected = array($this->getMatch()->getMeta($name));
        $vertical = true;
        $desctiption = __('Change to "On time" when time of match start will be actual. Or match started or has results.', 'msp');
        $multibple = false;
        
        $options = array(
            array(
                'id' => " ",
                'name' => __('On time', 'msp')
            ),
            array(
                'id' => (string)\MSP\DataType\MatchStatus::TBD,
                'name' => __('TBD', 'msp')
            ),
            array(
                'id' => (string)\MSP\DataType\MatchStatus::POSTPONNED,
                'name' => __('Postponed', 'msp')
            ),
            array(
                'id' => (string)\MSP\DataType\MatchStatus::CANCELED,
                'name' => __('Canceled', 'msp')
            ),
        );
        
        include $this->getPartTemplatePath('selector');
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getMatch()
    {
        return $this->getPostModel();
    }
}