<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\MetaBox;

class MatchPlayerStatistic extends AbstractMetaBox
{
    public function __construct()
    {
        $this->setId('match-player-statistic');
        $this->setTitle('Players');
        $this->setPosition('normal');
        $this->setPriority('high');
    }
    
    public function processing(\MSP\WPObjects\Model\AbstractPostModel $Post, $data)
    {
        return $data;
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getMatch()
    {
        return $this->getPostModel();
    }
    
    public function renderPlayeMatchDataInput(\MSP\Model\Player $Player, $model_type_id, $lable, $vertical = true, $desctiption = "", $multibple = false)
    {
        $Factory = $this->getServiceManager()->get('ModelTypeFactory');
        $ModelType = $Factory->get($model_type_id);
        
        $Game = $this->getGame();
        $options_filters = array();
        if ($Game && $ModelType->hasQualifier(\MSP\DataType\ModelType::GAME)) {
            $filter_name = $ModelType->getQualifierAttrName(\MSP\DataType\ModelType::GAME);
            $options_filters[$filter_name] = $Game->getId();
        }
        
        $Models = $ModelType->getFactory()->query($options_filters)->getResult();
        if (!count($Models)) {
            return '';
        }
        
        $options = array();
        foreach ($Models as $Model) {
            $options[] = array(
                'id' => $Model->getId(),
                'name' => $Model->getName(),
                'img' => $Model->getImgForSelect()
            );
        }
        
        $lable = $lable ? $lable : $ModelType->getName();
        
        $qualifier = $Player->getModelType()->getQualifierAttrName($model_type_id);
        $selected = $this->getMatch()->getPlayerData($Player->getId(), $qualifier);
        $name = $this->getMatch()->getPlayerMatchDataKey($Player->getId()) . "[$qualifier]";
        
        if (!is_array($selected)) {
            $selected = array($selected);
        }
        
        if ($ModelType instanceof \MSP\WPObjects\PostType\PostType) {
            $add_new_link = $ModelType->getAddNewLink();
            $add_new_text = $ModelType->getLabels('add_new_item');                     
        } else {
            $add_new_link = $this->getAddNewEntryLink();
            $add_new_text = __('Add new entry to') . ' ' . $ModelType->getName();
        }
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function getPlayerMatchDataCheckbox($Player, $name, $lable)
    {
        $value = $this->getMatch()->getPlayerData($Player->getId(), $name) ? true : false;
        $meta_attr_name = $this->getMatch()->getPlayerMatchDataKey($Player->getId()) . "[$name]";
        $desctiption = "";
        $empty_value = 0;
        
        include $this->getPartTemplatePath('checkbox');
    }
    
    public function renderPlayerStatInput(\MSP\Model\TeamStatisticType $Stat, \MSP\Model\Player $Player)
    {
        $data_key = $this->getMatch()->getPlayerMatchDataKey($Player->getId());
        $stat_id = $Stat->getId();
        
        $value = $this->getMatch()->getPlayerData($Player->getId(), $stat_id);
        $meta_attr_name = $data_key . "[$stat_id]";
        $step = '0.01';
        $type = 'number';
        $description = '';
        $vertical = false;
        $lable = $Stat->getName();
        $balance_with = true;
        
        include $this->getPartTemplatePath('custom-input');
    }
    
    public function getPlayerDataTeamInputName(\MSP\Model\Player $Player)
    {
        $data_key = $this->getMatch()->getPlayerMatchDataKey($Player->getId());
        $attr = $Player->getModelType()->getQualifierAttrName(\MSP\DataType\ModelType::TEAM);
        return $data_key . "[$attr]";
    }
}