<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\MetaBox;

use MSP\DataType\ModelType;

class MatchSelectTeam extends AbstractMetaBox
{
    public function __construct()
    {
        $this->setId('match-select-team');
        $this->setTitle('Matchmaking');
        $this->setPosition('normal');
        $this->setPriority('high');
        
        add_action('add_meta_boxes', array($this, 'postMetaRequire'), 1000, 2);
    }
    
    public function postMetaRequire($post_type, $post)
    {
        if (!in_array($post_type, array(
            ModelType::MATCH
        ))) {
            return;
        }
        
        $this->Post = $post;
        $PostType = $this->getPostType();
        $PostModel = $this->getPostModel();
        
        $value = $PostModel->getMeta('_organisation_id');
        $game_id = $PostModel->getMeta('_game_id');
        
        if ((!$value || count($value) < 2) && $game_id) {
            
            foreach ($PostType->getMetaBoxes() as $MetaBox) {
                if ($MetaBox->getId() === $this->getId()) {
                    continue;
                }
                
                \remove_meta_box($MetaBox->getId(), $post_type, $MetaBox->getPosition());
            }

            \remove_post_type_support($post_type, 'title');
            \remove_post_type_support($post_type, 'excerpt');
            \remove_meta_box('postimagediv', $post_type, 'side');
            
        } else {
            \remove_meta_box($this->getId(), $post_type, $this->getPosition());
        }
        
        return $this;
    }
    
    public function processing(\MSP\WPObjects\Model\AbstractPostModel $Post, $data)
    {
        $attr = $Post->getModelType()->getQualifierAttrName(ModelType::TEAM);
        if (!isset($data[$attr]) || count($data[$attr]) < 2) {
            return array();
        }
        
        $teams_ids = $data[$attr];
        $Post->setMeta($attr, $teams_ids);
        $Teams = $this->getServiceManager()->get('TeamFactory')->get($teams_ids, array(), false);
        
        foreach ($Teams as $Team) {
            $Players = $Team->getPlayers();
            foreach ($Players as $Player) {
                $Post->addPlayer($Player->getId(), $Team->getId());
            }
            
            $trainers_ids = $Team->getTrainersIds();
            $Post->updateTrainers($trainers_ids, $Team->getId());
        }
        
        return array();
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getMatch()
    {
        return $this->getPostModel();
    }
}