<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\MetaBox;

class MatchTeamStatistic extends AbstractMetaBox
{
    public function __construct()
    {
        $this->setId('match-team-statistic');
        $this->setTitle('Teams');
        $this->setPosition('normal');
        $this->setPriority('high');
    }
    
    public function processing(\MSP\WPObjects\Model\AbstractPostModel $Post, $data)
    {
        if (!isset($data['lineups'])) {
            return $data;
        }
        
        foreach ($data['lineups'] as $team_id => $players_ids) {
            $string = explode('_', $team_id);
            if (!isset($string[1])) {
                continue;
            }
            
            $Team = $Post->getTeamById($string[1]);
            if (!$Team) {
                continue;
            }
            $Post->updatePlayers($players_ids, $Team->getId());
        }
        
        return $data;
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getMatch()
    {
        return $this->getPostModel();
    }
    
    public function renderHeroesBandSelector(\MSP\Model\Team $Team)
    {
        $options = array();
        $Heroes = $Team->getGame() ? $Team->getGame()->getHeroes() : array();
        
        foreach ($Heroes as $Hero) {
            $options[] = array(
                'id' => $Hero->getId(),
                'name' => $Hero->getName(),
                'img' => $Hero->getImgForSelect()
            );
        }
        
        $selected = $this->getMatch()->getTeamData($Team->getId(), '_dota_bans_heroes');
        
        $data_key = $this->getMatch()->getTeamMatchDataKey($Team->getId());
        $name = $data_key . '[_dota_bans_heroes]';
        $lable = $Team->getName() . ' Bans';
        $vertical = true;
        $desctiption = ""; 
        $multibple = true;
        
        $add_new_link = $this->getAddNewEntryLink();
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function renderPlayersSelector(\MSP\Model\Team $Team)
    {
        $options = array();
        $game_id = $this->getMatch()->getGameId();
        $Settings = $this->getServiceManager()->get('SettingsFactory');
        
        if ($Settings->getValue('select_players_in_match_type') === 'team_members') {
            $Players = $Team->getPlayers();
        } else {
            $Players = $this->getServiceManager()->get('PlayerFactory')->getByGame($game_id);
        }
        
        foreach ($Players as $Player) {
            $options[] = array(
                'id' => $Player->getId(),
                'name' => $Player->getName(),
                'img' => $Player->getImgForSelect()
            );
        }
        
        $lable = $Team->getName() . ' ' . __('Lineup', 'msp');
        $vertical = true;
        $desctiption = ""; 
        $multibple = true;
        $name = 'lineups[team_'. $Team->getId() .']';
        $selected = $this->getMatch()->getPlayersIdsByTeam($Team->getId());
        
        $add_new_link = $this->getServiceManager()->get('ModelTypePlayer')->getAddNewLink();
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function renderTrainersSelector(\MSP\Model\Team $Team)
    {
        $options = array();
        $Players = $this->getServiceManager()->get('TrainerFactory')->query()->getResult();
        foreach ($Players as $Player) {
            $options[] = array(
                'id' => $Player->getId(),
                'name' => $Player->getName(),
                'img' => $Player->getImgForSelect()
            );
        }
        
        $lable = $Team->getName() . ' ' . __('trainers', 'msp');
        $vertical = true;
        $desctiption = ""; 
        $multibple = true;
        $name = $this->getMatch()->getTeamMatchDataKey($Team->getId()) . '[trainers]';
        $selected = $this->getMatch()->getTrainersIdsByTeam($Team->getId());
        
        $add_new_link = $this->getServiceManager()->get('ModelTypeTrainer')->getAddNewLink();
        
        include $this->getPartTemplatePath('selector');
    }
    
    public function renderTeamStatInput(\MSP\Model\TeamStatisticType $Stat, \MSP\Model\Team $Team)
    {
        $data_key = $this->getMatch()->getTeamMatchDataKey($Team->getId());
        $stat_id = $Stat->getId();
        
        $value = $this->getMatch()->getTeamData($Team->getId(), $stat_id);
        $meta_attr_name = $data_key . "[$stat_id]";
        $step = '0.01';
        $type = 'number';
        $description = '';
        $vertical = false;
        $lable = $Stat->getName();
        $balance_with = true;
        
        include $this->getPartTemplatePath('custom-input');
    }
}