<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;
use MSP\DataType\ModelType;

class Broadcast extends AbstractModel
{
    public function isLive()
    {
        $Status = $this->getStatus();
        if (!$Status || $Status->getId() <= 50) {
            return false;
        }
        
        return true;
    }
    
    /**
     * @return \MSP\Model\AbstractPostModel
     */
    public function getStreamObject()
    {
        if ($this->getTeamPlayer()) {
            return $this->getTeamPlayer();
        } else if ($this->getTeam()) {
            return $this->getTeam();
        } else if ($this->getChampionship()) {
            return $this->getChampionship();
        }
        
        return $this;
    }
    
    public function getTwitchId()
    {
        return $this->getMeta('_steam_twitch_id');
    }
    
    /**
     * @return \MSP\Model\BroadcastStatus
     */
    public function getStatus()
    {
        return $this->getRelative(ModelType::BROADCAST_STATUS);
    }
    
    public function setStatusId($status_id)
    {
        $attr_name = $this->getModelType()->getQualifierAttrName(ModelType::BROADCAST_STATUS);
        $this->setMeta($attr_name, $status_id);
        
        return $this;
    }
    
    public function getTeam()
    {
        return $this->getRelative(ModelType::TEAM);
    }
    
    /**
     * @return \MSP\Model\Country
     */
    public function getCountry()
    {
        return $this->getRelative(ModelType::COUNTRY);
    }
    
    /**
     * @return \MSP\Model\Game
     */
    public function getGame()
    {
        return $this->getRelative(ModelType::GAME);
    }
    
    public function getChampionship()
    {
        return $this->getRelative(ModelType::CHAMPIONSHIP);
    }
    
    public function getTeamPlayer()
    {
        return $this->getRelative(ModelType::PLAYER);
    }
    
    public function getPrettyViewersCount()
    {
        $count = $this->getViewersCount();
        return number_format($count, 0, ',', ' ');
    }
    
    public function getViewersCount()
    {
        $count = $this->getMeta('_viewers_count');
        if (!$count) {
            return 0;
        }
        
        return $count;
    }
    
    public function setViewersCount($int)
    {
        $this->setMeta('_viewers_count', $int);
        
        return $this;
    }
    
    public function getLastLiveDate()
    {
        return $this->getMeta('_last_live_date');
    }
    
    public function setLastLiveDate($date)
    {
        $this->setMeta('_last_live_date', $date);
        
        return $this;
    }
    
    public function getLastScreenshotUrl()
    {
        return $this->getMeta('_last_screenshot_url');
    }
    
    public function setLastScreenshotUrl($url)
    {
        $this->setMeta('_last_screenshot_url', $url);
        
        return $this;
    }
    
    public function getCoverImage($size = 'medium')
    {
        $attachment_id = $this->getMeta('_broadcast_bg');
        if (!$attachment_id) {
            return '';
        }

        $url_attachment = \wp_get_attachment_image_url($attachment_id, $size);
        return $url_attachment;
    }
    
    public function getStreamCoverImageUrl()
    {
        $screenshot_url = $this->getLastScreenshotUrl();
        if ($screenshot_url) {
            return $screenshot_url;
        }
        
        return $this->getCoverImage('large');
    }
    
    /**
     * Return broadcast commentators
     * 
     * @return \MSP\Model\Commentator in array
     */
    public function getCommentators()
    {
        return $this->getRelative(ModelType::COMMENTATOR, array(), false);
    }
    
    public function getContent()
    {
        $content = parent::getContent();
        if (strpos($content, '<iframe') !== false) {
            return '';
        }
        
        return $content;
    }
    
    public function getPlayer()
    {
        if ($this->getTwitchId()) {
            $twitch_id = $this->getTwitchId();
            return '<iframe src="https://player.twitch.tv/?channel='. $twitch_id .'" frameborder="0" allowfullscreen="true" scrolling="no" width="100%" height="100%"></iframe>';
        }
        
        if (!isset($this->post_content)) {
            return '';
        }

        return $this->post_content;
    }
}