<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;
use MSP\DataType\ModelType;
use MSP\DataType\MatchStatus;
use MSP\WPObjects\Date\WordPress as WPDate;

class Championship extends AbstractModel
{
    /**
     * @return \MSP\Model\Game
     */
    public function getGame()
    {
        return $this->getRelative(ModelType::GAME);
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getMatches()
    {
        return $this->getRelative(ModelType::MATCH, array(), false);
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getNextMatchWithBroadcast()
    {
        return $this->getRelative(ModelType::MATCH, array(
            'numberposts' => 1,
            '_match_status' => (string)MatchStatus::EXPECTED,
            'broadcasts_exists' => true
        ));
    }
    
    public function getYear()
    {
        $_date_start = $this->getMeta('_date_start');
        $time = strtotime($_date_start);
        if (!$time) {
            return '';
        }

        return date('Y', $time);
    }
    
    public function getDates($format = 'j F Y')
    {
        $_date_start = $this->getMeta('_date_start');
        $_date_end = $this->getMeta('_date_end');

        $start = WPDate::formatFromString($_date_start, $format);
        $end = WPDate::formatFromString($_date_end, $format);

        return $start . ' - ' . $end; 
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getLastMatch()
    {
        return $this->getRelative(ModelType::MATCH, array(
            'numberposts' => 1,
            '_match_status' => (string)MatchStatus::FINISHED,
        ));
    }
    
    public function getTeams()
    {
        return $this->getRelative(ModelType::TEAM, array(), false);
    }
    
    public function getTeamsIds()
    {
        return $this->getRelativeId(ModelType::TEAM, false);
    }
    
    public function getAttributes()
    {
        $atts = $this->getMeta('_attrs');
        if (!$atts) {
            return array();
        }
        
        return $atts;
    }
    
    public function getLiveMatches()
    {
        return $this->getRelative(ModelType::MATCH, array(
            '_match_status' => (string)MatchStatus::LIVE,
        ), false);
    }
    
    public function getLiveMatch()
    {
        return $this->getRelative(ModelType::MATCH, array(
            'numberposts' => 1,
            '_match_status' => (string)MatchStatus::LIVE,
        ), true);
    }
    
    public function isLive()
    {
        if (count($this->getLiveMatches())) {
            return true;
        }
        
        return false;
    }
    
    /**
     * @return \MSP\Model\Team
     */
    public function getWinners()
    {
        $TeamFactory = $this->getServiceManager()->get('TeamFactory');
        $ids = $this->getMeta('_organisation_winners');
        if (!$ids) {
            return array();
        }
        
        return $TeamFactory->get($ids, array(), false);
    }
}