<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;
use MSP\DataType\ModelType;

class MatchEvent extends AbstractModel
{
    public function getPlayer()
    {
        return $this->getRelative(ModelType::PLAYER);
    }
    
    public function getEventType()
    {
        return $this->getRelative(ModelType::MATCH_EVENT_TYPE);
    }
    
    public function getEventMinute($format = 'M')
    {
        $time = $this->getMeta('_match_time');
        
        if (!$time) {
            return 0;
        }
        
        $elements = explode(':', $time);

        if (count($elements) === 1) {
            $seconds = (int)$elements[0];
            $minutes = 0;
            $hours = 0;
        } elseif (count($elements) === 2) {
            $seconds = (int)$elements[1];
            $minutes = (int)$elements[0];
            $hours = 0;
        } else {
            $seconds = (int)$elements[2];
            $minutes = (int)$elements[1];
            $hours = (int)$elements[0];
        }

        if ($format == "M") {
            return ($hours * 60) + $minutes;
        } elseif ($format == "H") {
            return $hours;
        } elseif ($format == "S") {
            return ($hours * 60 * 60) + ($minutes * 60) + $seconds;
        }

        return 0;
    }
    
    public function getTooltipString()
    {
        $tooltip = '';
        $event_type = $this->getEventType();
        $Player = $this->getPlayer();
        
        if (!$Player) {
            $tooltip .= esc_attr( $this->getEventMinute('M') . '’ ' );
            $tooltip .= esc_attr( $event_type->getName() );
        } else {
            $tooltip .= esc_attr( $this->getEventMinute('M') . '’ ' );
            $tooltip .= esc_attr( $Player->getName() );
        }

        return $tooltip;
    }
    
    public function getIconUrl()
    {
        $EventType = $this->getEventType();
        
        if ($EventType->get('img_url')) {
            return $EventType->get('img_url');
        }
        
        return null;
    }
}