<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;
use MSP\DataType\ModelType;

class Player extends AbstractModel
{
    /**
     * @var \MSP\Model\Game
     */
    protected $Game = null;
    
    /**
     * @var \MSP\Model\Team
     */
    protected $Team = null;
    
    public function getAttributes()
    {
        $atts = $this->getMeta('_attrs');
        if (!$atts) {
            return array();
        }
        
        return $atts;
    }
    
    public function getSocial()
    {
        $socials = $this->getMeta('_socials');
        if (!is_array($socials) || !current(current($socials))) {
            return array();
        }

        return $socials;
    }
    
    /**
     * @return \MSP\Model\Game
     */
    public function getGame()
    {
        return $this->getRelative(ModelType::GAME);
    }
    
    public function getTeam()
    {
        return $this->getRelative(ModelType::TEAM);
    }
    
    public function getTeamName()
    {
        $Team = $this->getTeam();
        return $Team ? $Team->getName() : 'N\A';
    }
    
    public function getTeamId()
    {
        return $this->getRelativeId(ModelType::TEAM);
    }
    
    public function getRoleId()
    {
        return $this->getRelativeId(ModelType::PLAYER_ROLE);
    }
    
    public function getRole()
    {
        $Game = $this->getGame();
        return $this->getRelative(ModelType::PLAYER_ROLE, array(
            '_game_id' => $Game->slug
        ));
    }
    
    /**
     * @return \MSP\Model\Trophy
     */
    public function getAllTrophies()
    {
        $result_trophies = array();
        $Teams = $this->getTeamsHistory();
        foreach ($Teams as $Team) {
            $result_trophies = array_merge($result_trophies, $Team->getTrophies());
        }
        
        $OwnTrophies = $this->getTrophies();
        foreach ($OwnTrophies as $Trophy) {
            if (!in_array($Trophy, $result_trophies)) {
                $result_trophies[] = $Trophy;
            }
        }
        
        return $result_trophies;
    }
    
    public function getTrophies()
    {
        return $this->getRelative(ModelType::TROPHI, array(), false);
    }
    
    public function getTrophiesIds()
    {
        return $this->getRelativeId(ModelType::TROPHI, false);
    }
    
    public function getHeroId()
    {
        return $this->getRelativeId(ModelType::PLAYER_HERO);
    }
    
    public function getHero()
    {
        $Game = $this->getGame();
        return $this->getRelative(ModelType::PLAYER_HERO, array(
            '_game_id' => $Game->slug
        ));
    }
    
    public function getPosition()
    {
        $Game = $this->getGame();
        $Position = $this->getRelative(ModelType::PLAYER_POSITION, array(
            'game_id' => $Game->slug
        ));
        
        return apply_filters('team_get_player_position', $Position, $this->ID);
    }
    
    public function getPositionId()
    {
        return $this->getRelativeId(ModelType::PLAYER_POSITION);
    }
    
    public function getPositionName()
    {
        $Position = $this->getPosition();
        if (!$Position) {
            return '';
        }
        
        return $Position->getName();
    }
    
    public function getPlayerActivity()
    {
        return $this->getRelative(ModelType::PLAYER_TEAM_ACTIVITY);
    }
    
    public function getPlayerActivityId()
    {
        return $this->getRelativeId(ModelType::PLAYER_TEAM_ACTIVITY);
    }
    
    public function getPlayerNumber()
    {
        return (string)$this->getMeta('_player_number');
    }
    
    public function isCapitan()
    {
        return $this->getMeta('_player_capitan') ? true : false;
    }
    
    public function getAge()
    {
        $birthday = $this->getMeta('_player_birthday');
        if (!$birthday) {
            return '';
        }

        $date = new \DateTime($birthday);
        $now = new \DateTime();
        $interval = $now->diff($date);
        return $interval->y;
    }
    
    public function getFullName()
    {
        return $this->getMeta('_player_full_name');
    }
    
    public function getCity()
    {
        return $this->getMeta('_player_city');
    }
    
    public function getWeight()
    {
        return $this->getMeta('_player_weight');
    }
    
    public function getHeight()
    {
        return $this->getMeta('_player_height');
    }
    
    public function getMatches()
    {
        return $this->getRelative(ModelType::MATCH, array(), false);
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getFinishedMatches($matche_filters = array())
    {
        return $this->getRelative(ModelType::MATCH, array_merge($matche_filters, array('_match_status' => '2')), false);
    }
    
    public function getTeamsHistoryIds()
    {
        /* @var $Match \MSP\Model\Match */
        
        $matches = $this->getMatches();
        $teams_ids = array();
        foreach ($matches as $Match) {
            $teams_ids[] = $Match->getPlayerData($this->getId(), '_organisation_id');
        }

        $current_team_id = $this->getTeamId();
        array_unshift($teams_ids, $current_team_id);
        return array_unique( $teams_ids );
    }
    
    /**
     * @return \MSP\Model\Team
     */
    public function getTeamsHistory()
    {
        $team_ids = $this->getTeamsHistoryIds();
        $TeamsFactory = $this->getServiceManager()->get('TeamFactory');
        return $TeamsFactory->get($team_ids, array(), false);
    }
    
    public function getCurrentStatistic($stat_id = null)
    {
        $stat = team_get_player_stat(array('_player_id' => $this->getId()));
        if (is_null($stat_id)) {
            return $stat;
        }
        
        return isset($stat[$stat_id]) ? $stat[$stat_id] : '';
    }
    
    public function getStatisticFromCache($stat_id = null)
    {
        $player_stats = $this->getMeta($this->getStatisticCacheKey());
        if (!$player_stats || $player_stats == "" || !is_array($player_stats)) {
            $statistics = array();
        } else {
            $statistics = $player_stats;
        }

        if (is_null($stat_id)) {
            return $statistics;
        }
        
        return isset($statistics[$stat_id]) ? $statistics[$stat_id] : 0;
    }
    
    public function getStatisticCacheKey()
    {
        return '_player_stats';
    }
    
    public function getStatisticFromOnceCache($stat_id)
    {
        $value = $this->getMeta($this->getStatisticOnceCacheKey($stat_id));
        return $value ? $value : 0;
    }
    
    public function getStatisticOnceCacheKey($stat_id)
    {
        return '_player_stat_cache_' . $stat_id;
    }
    
    public function getCountry()
    {
    }
    
    public function getDataForMatch($team_id = null)
    {
        $match_team_id = $team_id ? $team_id : $this->getTeamId();
        
        $MT = $this->getModelType();
        
        $player_data = array(
            $MT->getQualifierAttrName(ModelType::TEAM) => $match_team_id,
            $MT->getQualifierAttrName(ModelType::PLAYER_POSITION) => $this->getPositionId(),
            $MT->getQualifierAttrName(ModelType::PLAYER_TEAM_ACTIVITY) => $this->getPlayerActivityId(),
            $MT->getQualifierAttrName(ModelType::PLAYER_ROLE) => $this->getRoleId(),
            $MT->getQualifierAttrName(ModelType::PLAYER_HERO) => $this->getHeroId(),
            $MT->getQualifierAttrName(ModelType::PLAYER_ITEM) => array(),
            '_player_capitan' => $this->isCapitan(),
        );
        
        return $player_data;
    }
    
    public function getStatisticTypes($filters = array())
    {
        $Game = $this->getGame();
        if (!$Game) {
            return array();
        }
        
        return $Game->getPlayerStatisticTypes($filters);
    }
    
    /**
     * Updating statistic index with out model saving
     * @return $this
     */
    public function updateStatisticIndex()
    {
        $player_stats = $this->getPlayerStatistic();
        $this->setMeta('_player_stats', $player_stats);
        
        $StatisticTypes = $this->getStatisticTypes();
        
        foreach ($StatisticTypes as $StatisticType) {
            $stat_key = $StatisticType->getId();
            $value = isset($player_stats[$stat_key]) ? $player_stats[$stat_key] : 0;
            $this->setMeta($this->getStatisticOnceCacheKey($stat_key), $value);
        }
        
        return $this;
    }
    
    public function cleatStatisticIndex()
    {
        $this->setMeta('_player_stats', null);
        $StatisticTypes = $this->getStatisticTypes();
        foreach ($StatisticTypes as $StatisticType) {
            $stat_key = $StatisticType->getId();
            $this->setMeta($this->getStatisticOnceCacheKey($stat_key), null);
        }
        
        return $this;
    }
    
    public function getPlayerStatistic($matche_filters = array())
    {
        $Matches = $this->getFinishedMatches($matche_filters);
        $count = count($Matches);

        $StatisticTypes = $this->getStatisticTypes(array('ui' => true));

        $result = array();
        $result['matches'] = $count;
        $result['wins'] = 0;
        $result['loses'] = 0;
        $result['draws'] = 0;

        foreach ($Matches as $match) {
            if ($match->isPlayerPlaying($this->getId()) === false) {
                continue;
            }
            
            $stats = $match->getPlayerData($this->getId());
            
            foreach ($StatisticTypes as $StatisticType) {
                $key = $StatisticType->getId();
                if (isset($stats[$key]) && is_numeric($stats[$key])) {
                    $value = $stats[$key];
                } else {
                    continue;
                }

                if (isset($result[$key])) {

                    $result[$key . '_max'] = $value > $result[$key] ? $value : $result[$key];
                    $result[$key . '_min'] = $value < $result[$key] ? $value : $result[$key];
                    $result[$key] = $result[$key] + $value;
                    $result[$key . '_rate'] = round($result[$key] / $count, 2);

                } else {

                    $result[$key] = $value;
                    $result[$key . '_rate'] = $value;
                    $result[$key . '_max'] = $value;
                    $result[$key . '_min'] = $value;

                }
            }

            $match_result = $match->isPlayerWinner($this->getId());
            if ($match_result === "draw") {
                $result['draws'] = $result['draws'] + 1;
            } elseif ($match_result === true) {
                $result['wins'] = $result['wins'] + 1;
            } else {
                $result['loses'] = $result['loses'] + 1;
            }
        }

        if ($result['wins'] !== 0) {
            $result['win_rate'] = round($result['wins'] / ($result['loses'] + $result['wins']) * 100, 2);
        } else {
            $result['win_rate'] = 0;
        }

        return $result;
    }
}