<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;

class Standing extends AbstractModel
{
    
    public function getStateCount()
    {
        $value = $this->getMeta('_stage_count');
        if (!$value || $value < 1) {
            return 0;
        }
        
        return $value;
    }
    
    public function getScoreType()
    {
        return $this->getMeta('_score_type');
    }
    
    /**
     * @return \MSP\Model|Championship
     */
    public function getChamp()
    {
        return $this->getRelative(\MSP\DataType\ModelType::CHAMPIONSHIP);
    }
    
    public function getStages()
    {
        $data = array();
        $count = 1;
        for ($i = 0; $i < $this->getStateCount(); $i++) {
            $current_stage = $i + 1;
            $stage_matches_ids = $this->getMeta('_stage_' . $current_stage);

            $data[$current_stage] = array();
            for ($c = 0; $c < $count; $c++) {
                $data[$current_stage][] = isset($stage_matches_ids[$c]) ? $stage_matches_ids[$c] : false;
            }

            $count = $count * 2;
        }
        
        krsort($data);
        return $data;
    }
    
    public function toJqueryBracket()
    {
        $standing_id = $this->getId();
        $_stage_count = $this->getStateCount();
        $_score_type = $this->getScoreType();
        if ($_stage_count < 1) {
            return array();
        }        

        $teams = array();
        $results = array();

        for ($i = 0; $i < $_stage_count; $i++) {
            $stage = $i + 1;
            $var = '_stage_' . $stage;
            $stage_team = array();
            $stage_results = array();

            $stage_data = get_post_meta($standing_id, $var, true);
            foreach ($stage_data as $stage_matches) {
                if (!is_array($stage_matches)) {
                    continue;
                }

                $team_left = team_get_match_team($stage_matches[0], 0);
                $team_right = team_get_match_team($stage_matches[0], 1);
                $stage_team[] = array(
                    $this->getItemName($team_left),
                    $this->getItemName($team_right)
                );

                $result_team_1 = 0;
                $result_team_2 = 0;
                if ($_score_type == "wins") {
                    foreach ($stage_matches as $match_id) {
                        if (msp_is_match_organisation_win($match_id, $team_left->ID)) {
                            $result_team_1++;
                        } else {
                            $result_team_2++;
                        }
                    }
                } elseif ($_score_type == "score") {
                    $result_team_1 = (int)msp__get_match_team_main_score($stage_matches[0], $team_left->ID);
                    $result_team_2 = (int)msp__get_match_team_main_score($stage_matches[0], $team_right->ID);
                }

                $stage_results[] = array($result_team_1, $result_team_2);
            }

            $teams[] = $stage_team;
            $results[] = $stage_results;
        }

        $teams = array_reverse($teams);

        return array(
            'teams' => $teams[0], 
            'results' => array_reverse($results)
        );
    }
    
    protected function getItemName($Team)
    {
        return  '<a href="'. get_the_permalink($Team->getId()) .'">' . get_the_post_thumbnail($Team->getId(), array(32, 32)) . '</a>' .
            ' ' . $Team->getName();
    }
}