<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\Model;

use MSP\Model\AbstractPostModel as AbstractModel;
use MSP\DataType\ModelType;
use MSP\WPObjects\Data\DataType;

class Team extends AbstractModel
{
    /**
     * @return \MSP\Model\Game
     */
    public function getGame()
    {
        return $this->getRelative(ModelType::GAME);
    }
    
    public function getTrophies()
    {
        return $this->getRelative(ModelType::TROPHI, array(), false);
    }
    
    public function getTrainers()
    {
        return $this->getRelative(ModelType::TRAINER, array(), false);
    }
    
    public function getTrainersIds()
    {
        return $this->getRelativeId(ModelType::TRAINER, false);
    }
    
    public function getPlayers()
    {
        return $this->getRelative(ModelType::PLAYER, array(), false);
    }
    
    /**
     * @return \MSP\Model\Country
     */
    public function getCountry()
    {
        return $this->getRelative(ModelType::COUNTRY);
    }
    
    public function getStatisticTypes($filters = array())
    {
        $Game = $this->getGame();
        if (!$Game) {
            return array();
        }
        
        return $Game->getTeamStatisticTypes($filters);
    }
    
    public function getAttributes()
    {
        $atts = $this->getMeta('_attrs');
        if (!is_array($atts) || !current(current($atts))) {
            return array();
        }
        
        return $atts;
    }
    
    public function getSocial()
    {
        $socials = $this->getMeta('_socials');
        if (!is_array($socials) || !current(current($socials))) {
            return array();
        }

        return $socials;
    }
    
    /**
     * @return \MSP\Model\Match
     */
    public function getFinishedMatches($matche_filters = array())
    {
        return $this->getRelative(ModelType::MATCH, array_merge($matche_filters, array('_match_status' => \MSP\DataType\MatchStatus::FINISHED)), false);
    }
    
    /**
     * @param array $filters
     * @return \MSP\Model\Match
     */
    public function getMatches($filters = array())
    {
        return $this->getRelative(ModelType::MATCH, $filters, false);
    }

    public function getNextMatchByChmp($chmp_id)
    {
        $ModelTypeMatch = $this->getServiceManager()->get('ModelTypeMatch');
        $chmp_attr = $ModelTypeMatch->getQualifierAttrName(ModelType::CHAMPIONSHIP);

        $matches_filter = array();
        $matches_filter[$chmp_attr] = $chmp_id;

        return $this->getNextMatch($matches_filter);
    }

    public function getNextMatch($filters = array())
    {
        $filters = array_merge($filters, array(
            'numberposts' => -1,
            '_match_status' => 0,
            'orderby' => '_date_start',
            'order' => 'ASC',
            'orderby_type' => 'DATETIME'
        ));

        $next_match = $this->getMatches($filters);
        if (current($next_match)) {
            return current($next_match);
        }

        return null;
    }

    public function getLatestMatchesByChmp($chmp_id, $count = 5)
    {
        /* @var $ModelTypeMatch \MSP\WPObjects\Model\AbstractModelType */
        $ModelTypeMatch = $this->getServiceManager()->get('ModelTypeMatch');
        $chmp_attr = $ModelTypeMatch->getQualifierAttrName(ModelType::CHAMPIONSHIP);

        $matches_filter = array();
        $matches_filter[$chmp_attr] = $chmp_id;

        return $this->getLatestMatches($count, $matches_filter);
    }

    public function getLatestMatches($count = 5, $filters = array())
    {
        return $this->getFinishedMatches(array_merge($filters, array(
            'numberposts' => $count,
            'orderby' => '_date_start',
            'order' => 'DESC'
        )));
    }
    
    public function getStatisticOnceCacheKey($stat_id)
    {
        return '_organisation_stat_cache_' . $stat_id;
    }
    
    public function getStatChacheById($stat_id)
    {
        $meta_id = $this->getStatisticOnceCacheKey($stat_id);
        $value = $this->getMeta($meta_id);
        return $value ? $value : 0;
    }
    
    /**
     * Updating statistic index with out model saving
     * @return $this
     */
    public function updateStatisticIndex()
    {
        $player_stats = $this->getStatistic();
        $this->setMeta('_organisation_stats', $player_stats);
        
        $StatisticTypes = $this->getStatisticTypes();
        
        foreach ($StatisticTypes as $StatisticType) {
            $stat_key = $StatisticType->getId();
            $value = isset($player_stats[$stat_key]) ? $player_stats[$stat_key] : 0;
            $this->setMeta($this->getStatisticOnceCacheKey($stat_key), $value);
        }
        
        return $this;
    }
    
    public function cleatStatisticIndex()
    {
        $this->setMeta('_organisation_stats', null);
        $StatisticTypes = $this->getStatisticTypes();
        
        foreach ($StatisticTypes as $StatisticType) {
            $stat_key = $StatisticType->getId();
            $this->setMeta($this->getStatisticOnceCacheKey($stat_key), null);
        }
        
        return $this;
    }

    public function getStatisticByChmp($chmp_id)
    {
        /* @var $ModelTypeMatch \MSP\WPObjects\Model\AbstractModelType */
        $ModelTypeMatch = $this->getServiceManager()->get('ModelTypeMatch');
        $qualifier_attr = $ModelTypeMatch->getQualifierAttrName(ModelType::CHAMPIONSHIP);

        $match_filter = array();
        $match_filter[$qualifier_attr] = $chmp_id;

        return $this->getStatistic($match_filter);
    }

    public function getStatistic($matche_filters = array())
    {
        $Matches = $this->getFinishedMatches($matche_filters);
        $count = count($Matches);

        $StatisticTypes = $this->getStatisticTypes(array('ui' => true));

        $result = array();
        $result['matches'] = $count;
        $result['wins'] = 0;
        $result['loses'] = 0;
        $result['draws'] = 0;

        foreach ($Matches as $match) {
            $stats = $match->getTeamData($this->getId());
            
            foreach ($StatisticTypes as $StatisticType) {
                $key = $StatisticType->getId();
                if (isset($stats[$key]) && is_numeric($stats[$key])) {
                    $value = $stats[$key];
                } else {
                    continue;
                }

                if (isset($result[$key])) {

                    $result[$key . '_max'] = $value > $result[$key] ? $value : $result[$key];
                    $result[$key . '_min'] = $value < $result[$key] ? $value : $result[$key];
                    $result[$key] = $result[$key] + $value;
                    $result[$key . '_rate'] = round($result[$key] / $count, 2);

                } else {

                    $result[$key] = $value;
                    $result[$key . '_rate'] = $value;
                    $result[$key . '_max'] = $value;
                    $result[$key . '_min'] = $value;

                }
            }

            $match_result = $match->isTeamWinner($this->getId());
            if ($match_result === "draw") {
                $result['draws'] = $result['draws'] + 1;
            } elseif ($match_result === true) {
                $result['wins'] = $result['wins'] + 1;
            } else {
                $result['loses'] = $result['loses'] + 1;
            }
        }

        if ($result['wins'] !== 0) {
            $result['win_rate'] = round($result['wins'] / ($result['loses'] + $result['wins']) * 100, 2);
        } else {
            $result['win_rate'] = 0;
        }

        return $result;
    }
}