<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\VC\Helpers;

class PlayerMatchData
{
    static function getBase()
    {
        $ms = \MSP\WPObjects\Service\Manager::getInstance();
        $ModelTypePlayer = $ms->get('ModelTypeFactory')->get(\MSP\DataType\ModelType::PLAYER);
        $ShorcodeParams = new \MSP\WPObjects\VC\ShorcodeParams();
        $ordering_params = $ShorcodeParams->genOrderingParams($ModelTypePlayer);
        
        foreach ($ordering_params as $key => $ordering_param) {
            $param_name = $ordering_param['param_name'];
            if ($param_name === 'numberposts') {
                unset($ordering_params[$key]);
                continue;
            }
            
            $ordering_params[$key]['group'] = __( 'Player match data', 'msp' );
            $ordering_params[$key]['param_name'] = 'player_match_data_' . $param_name;
        }
        
        $default = array(
            array(
                'type' => 'autocomplete',
                'heading' => __( 'Players by positions', 'msp' ),
                'param_name' => '_player_position_id',
                'group' => __( 'Player match data', 'msp' ),
                'settings' => array(
                    'multiple' => true,
                    'unique_values' => true,
                    'display_inline' => true,
                    'delay' => 500,
                    'sortable' => true,
                    'groups' => false,
                    'auto_focus' => true,
                    'values' => msp_get_player_positions_for_autocomplete(),
                ),
            ),
            array(
                'type' => 'autocomplete',
                'heading' => __( 'Players by activity in match', 'msp' ),
                'param_name' => '_player_team_activity_id',
                'group' => __( 'Player match data', 'msp' ),
                'description' => __('Variations: Primary staff (on the field), Secondary staff, Inactive or Dropped', 'msp'),
                'settings' => array(
                    'multiple' => true,
                    'unique_values' => true,
                    'display_inline' => true,
                    'delay' => 500,
                    'sortable' => true,
                    'groups' => false,
                    'auto_focus' => true,
                    'values' => msp_get_player_activity_for_autocomplete(),
                ),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Captains', 'msp' ),
                'description' => __('Checked this, for select only teams captains.', 'msp'),
                'param_name' => '_player_capitan',
                'group' => __( 'Player match data', 'msp' )
            ),
        );
        
        return array_merge($default, $ordering_params);
    }
}