<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\VC\Shortcodes;

use MSP\DataType\Game;

class MatchDotaTable extends \MSP\WPObjects\VC\Shortcode\DefaultShortcode
{
    public function render_table($team_id, $stats, \MSP\Model\Match $match)
    {
        $players = $match->getPlayersByMatchData( array('_organisation_id' => $team_id, '_player_team_activity_id' => 'primary_staff') );
        $Game = $match->getGame();
        
        ?>
        <table class="dota-match-results">
            <tbody>
                <tr>
                    <th><?php esc_html_e('Hero/Player', 'msp'); ?></th>
                    <th><?php esc_html_e('LVL', 'msp'); ?></th>
                    <th></th>
                    <?php if ($Game->getId() === Game::LOL) : ?>
                        <th class="player-spells"></th>
                    <?php endif; ?>
                    <th><?php esc_html_e('K/D/A', 'msp'); ?></th>
                    <th><?php esc_html_e('Items', 'msp'); ?></th>

                    <?php foreach ($stats as $stat) : ?>
                        <th><?php echo esc_html($stat['name']); ?></th>
                    <?php endforeach; ?>
                </tr>

                <?php
                foreach ($players as $player) :

                    $hero = $match->getPlayerHero($player->ID);
                    $player_stat = team_get_player_match_data($match->ID, $player->ID);
                    $items = $match->getPlayerItems($player->ID);
                    $spells = $Game->getId() === Game::LOL ? $match->getPlayerSpells($player->ID) : array();

                    ?>
                    <tr>
                        <td>
                            <a href="<?php echo get_permalink($player->ID); ?>">
                                <?php if ($hero): ?>
                                    <span class="hero-name"><?php echo esc_html($hero['name']); ?></span>
                                <?php endif; ?>
                                <span class="player-name"><?php echo get_the_title($player); ?></span>
                            </a>
                        </td>
                        <td>
                            <span class="lvl"><?php echo esc_html(isset($player_stat['lvl']) ? $player_stat['lvl'] : __('N/A', 'msp') ); ?></span>
                        </td>
                        <td class="padding-img">
                            <a href="<?php echo $hero ? esc_url($hero['link_wiki']) : ''; ?>">
                                <?php if ($hero) : ?>
                                    <img src="<?php echo esc_url($hero['img_full_url']); ?>" alt="player-hero">
                                <?php else: ?>
                                    <img src="<?php echo MSP_PATH_URL; ?>/images/Dota-2-Logo.png" alt="player-hero" class="baned">
                                <?php endif; ?>
                            </a>
                        </td>

                        <?php if ($Game->getId() === Game::LOL) : ?>
                        <td class="player-spells">
                            <?php foreach ($spells as $Spell) : ?>
                                <img src="<?php echo esc_url($Spell->get('img_url')); ?>" alt="<?php echo esc_attr($Spell->get('name')); ?>">
                            <?php endforeach; ?>
                        </td>
                        <?php endif; ?>

                        <td>
                            <?php echo esc_html(isset($player_stat['kills']) ? $player_stat['kills'] : __('N/A', 'msp') ); ?> / 
                            <?php echo esc_html(isset($player_stat['deaths']) ? $player_stat['deaths'] : __('N/A', 'msp') ); ?> /
                            <?php echo esc_html(isset($player_stat['assists']) ? $player_stat['assists'] : __('N/A', 'msp') ); ?>
                        </td>
                        <td>
                            <span class="items">
                                <?php foreach ($items as $item) : ?>
                                    <a href="<?php echo msp__get_dota_items_wiki_url(); ?>"><img src="<?php echo esc_url($item['img_full_url']); ?>" alt="<?php echo esc_attr($item['name']); ?>"></a>
                                <?php endforeach; ?>
                            </span>
                        </td>

                        <?php foreach ($stats as $key => $stat) : ?>
                            <td>
                                <?php echo esc_html(isset($player_stat[$stat['key']]) ? $player_stat[$stat['key']] : __('N/A', 'msp') ); ?>
                            </td>
                        <?php endforeach; ?>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
        <?php
    }
}