<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\VC\Shortcodes;

class TeamPlayerSlider extends \MSP\WPObjects\VC\Shortcode\DefaultShortcode
{
    /**
     * Return the special tabs objects
     */
    public function getTabsObjects($atts)
    {
        $TabsObjects = array();
        
        if (isset($atts['organisation_ids']) && strlen($atts['organisation_ids'])) {
            
            $teams = team_get_organisations(array(
                'id' => explode(', ', $atts['organisation_ids']),
                'max_count' => -1
            ));
            
            $TabsObjects = $this->createTabsObjects($teams);
            
            foreach ($TabsObjects as $team) {
                $players = team_get_players(array_merge($atts, array(
                    '_organisation_id' => $team->id,
                    'max_count' => -1
                )));
                $team->players = $players;
            }
            
        } else if (isset($atts['player_position_ids']) && strlen($atts['player_position_ids'])) {
            
            $positions = msp__get_player_position_by_ids(explode(', ', $atts['player_position_ids']), $atts['_game_id']);
            
            $TabsObjects = $this->createTabsObjects($positions);
            
            foreach ($TabsObjects as $position) {
                $players = team_get_players(array_merge($atts, array(
                    '_player_position_id' => $position->id,
                    'max_count' => -1
                )));
                $position->players = $players;
            }
            
        } else if (isset($atts['player_role_ids']) && strlen($atts['player_role_ids'])) {
            
            $roles = msp__get_player_roles_by_ids(explode(', ', $atts['player_role_ids']), $atts['_game_id']);
            
            $TabsObjects = $this->createTabsObjects($roles);
            
            foreach ($TabsObjects as $role) {
                $players = team_get_players(array_merge($atts, array(
                    '_player_role_id' => $role->id,
                    'max_count' => -1
                )));
                $role->players = $players;
            }
            
        } else {
            
            $players = team_get_players(array_merge($atts, array(
                'max_count' => -1
            )));
            
            $TabsObjects[] = new \ArrayObject(array(
                'players' => $players,
                'key' => str_shuffle('qwertyuiopasdfghjklzxcvbnm')
            ), \ArrayObject::ARRAY_AS_PROPS);
        }
        
        return $TabsObjects;
    }
    
    /**
     * @param type $othersObjects
     * @return \ArrayObject
     */
    protected function createTabsObjects($othersObjects)
    {
        $result = array();
        foreach ($othersObjects as $otherObject) {
            if ($otherObject instanceof WP_Post) {
                $result[] = new \ArrayObject(array(
                    'id' => $otherObject->ID,
                    'key' => $otherObject->post_name . '_' . str_shuffle('qwertyuiopasdfghjklzxcvbnm'),
                    'name' => get_the_title($otherObject)
                ), \ArrayObject::ARRAY_AS_PROPS);
            } else {
                $result[] = new \ArrayObject(array(
                    'id' => $otherObject->id,
                    'key' => $otherObject->id  . '_' . str_shuffle('qwertyuiopasdfghjklzxcvbnm'),
                    'name' => $otherObject->name
                ), \ArrayObject::ARRAY_AS_PROPS);
            }
        }
        
        return $result;
    }
    
}