<?php

/**
 * @encoding     UTF-8
 * @package      MSP - MultiSport & eSport WordPress plugin with 90 Visual Composer addons
 * @link         https://codecanyon.net/item/msp-multisport-esport-wordpress-plugin-with-90-visual-composer-addons/20954667
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

class msp_bootstrap
{
    static public function loadBase()
    {
        /**
        * Init WPObjects autoloader
        */
        include MSP_PATH . 'includes/vendor/WPObjects/Loader/NamespaceAutoloader.php';
        $Loader = new \MSP\WPObjects\Loader\NamespaceAutoloader();
        $Loader->addNamespace('MSP', MSP_PATH . 'includes/MSP');
        $Loader->addNamespace('MSP\WPObjects', MSP_PATH . 'includes/vendor/WPObjects');
        $Loader->register();
        
        /**
         * Service Manager initialization and configuration
         */
        $Manager = \MSP\WPObjects\Service\Manager::getInstance();
        $Manager->addConfig(include MSP_PATH . 'includes/vendor/WPObjects/config/service.manager.factory.config.php');
        $Manager->addConfig(include MSP_PATH . 'includes/MSP/config/service.manager.factories.php');
        $Manager->addNotStoredServicesConfig(include MSP_PATH . 'includes/vendor/WPObjects/config/not.stored.services.php');
        $Manager->addNotStoredServicesConfig(include MSP_PATH . 'includes/MSP/config/not.stored.services.php');
        
        /**
         * Helpers template tags
         */
        require_once MSP_PATH . '/includes/template-tags/broadcasts.php';
        require_once MSP_PATH . '/includes/template-tags/championships.php';
        require_once MSP_PATH . '/includes/template-tags/commentators.php';
        require_once MSP_PATH . '/includes/template-tags/country.php';
        require_once MSP_PATH . '/includes/template-tags/data.php';
        require_once MSP_PATH . '/includes/template-tags/games.php';
        require_once MSP_PATH . '/includes/template-tags/match.php';
        require_once MSP_PATH . '/includes/template-tags/match_events.php';
        require_once MSP_PATH . '/includes/template-tags/options.php';
        require_once MSP_PATH . '/includes/template-tags/organisation_stats.php';
        require_once MSP_PATH . '/includes/template-tags/organisations.php';
        require_once MSP_PATH . '/includes/template-tags/players.php';
        require_once MSP_PATH . '/includes/template-tags/players_stats.php';
        require_once MSP_PATH . '/includes/template-tags/products.php';
        require_once MSP_PATH . '/includes/template-tags/referee.php';
        require_once MSP_PATH . '/includes/template-tags/socials_sharing.php';
        require_once MSP_PATH . '/includes/template-tags/standings.php';
        require_once MSP_PATH . '/includes/template-tags/trainer.php';
        require_once MSP_PATH . '/includes/template-tags/trophies.php';
        require_once MSP_PATH . '/includes/template-tags/venue.php';
        require_once MSP_PATH . '/includes/template-tags/dota/heroes.php';
        require_once MSP_PATH . '/includes/template-tags/dota/items.php';
        require_once MSP_PATH . '/includes/template-tags/hearthstone/heroes.php';
        
        /**
         * Attach WordPress actions
         */
        require_once MSP_PATH . '/includes/wp-actions/match-events.php';
        require_once MSP_PATH . '/includes/wp-actions/matches.php';
        require_once MSP_PATH . '/includes/wp-actions/shortcode_tags.php';
        require_once MSP_PATH . '/includes/wp-actions/delete-team.php';
        
        /**
         * Backward compatibility
         */
        require_once MSP_PATH . '/includes/backward-compatibility/translate-vc-addon-presets.php';
        
        /**
         * Developing services, included only in develop version
         */
        if ( is_dir(MSP_PATH . '/includes/_services/') ) {
            require_once MSP_PATH . '/includes/_services/addon_colors_formating.php';
            require_once MSP_PATH . '/includes/_services/get_color_sheme_to_js.php';
            require_once MSP_PATH . '/includes/_services/match_auto_generate_statistic.php';
            require_once MSP_PATH . '/includes/_services/players_generator.php';
            require_once MSP_PATH . '/includes/_services/refactoring.php';
            require_once MSP_PATH . '/includes/_services/reset_default_template.php';
            require_once MSP_PATH . '/includes/_services/test-twitch.php';
        }
    }
    
    static public function setup()
    {
        $Manager = \MSP\WPObjects\Service\Manager::getInstance();
        
        /**
         * Added page cove image in to Pages
         */
        $ModelTypePage = $Manager->get('ModelTypePage');
        $MetaBoxPageCoverImage = $Manager->get('MetaBoxPageCoverImage');
        $ModelTypePage->addMetaBox($MetaBoxPageCoverImage);
        
        /**
         * Resgiter Post Types
         * @var $PostTypeManager \WPObjects\PostType\Manager
         */
        $PostTypeManager = $Manager->get('PostTypeManager');
        $PostTypeManager->attach();
        
        /**
         * Assets manager
         */
        $Manager->get('AssetsManager');
        
        /**
         * Register data types
         */
        $DataTypeFactory = $Manager->get('DataTypeFactory');
        $DataTypes = $DataTypeFactory->query()->getResult();
        foreach ($DataTypes as $DataType) {
            $DataType->attach();
        }

        /**
         * Register REST Controller for model types data
         */
        $Manager->get('DataTypeRestController')->attach();
        $Manager->get('UserSubscribeRegistrationListener')->attach();

        /**
         * attachment pages of WordPress admin-panel 
         */
        $Manager->get('DatabasePage')->attach();
        $Manager->get('SettingPage')->attach();
        $Manager->get('StatisticIndexPage')->attach();
        $Manager->get('TeamStatsPage')->attach();
        $Manager->get('PermalinksPage')->attach();
        $Manager->get('ExportImportPage')->attach();

        /**
         * Less compiler
         */
        $Manager->get('LessCompiler')->attach();
        
        /**
         * Cron tasks
         */
        $Manager->get('CronTwitchBroadcasts')->attach();
    }
    
    static public function loadVCAddons()
    {
        $Manager = \MSP\WPObjects\Service\Manager::getInstance();
        global $vc_manager;
        if (!isset($vc_manager)) {
            $AddonsStorage = $Manager->get('AddonsStorage');
            $AddonsStorage->close();
            $VCTemplateStorage = $Manager->get('VCTemplateStorage');
            $VCTemplateStorage->close();
            return;
        }
        
        $AddonsFactory = $Manager->get('AddonFactory');
        $Addons = $AddonsFactory->query()->getResult();
        foreach ($Addons as $Addon) {
            $Addon->attach();
        }
        
        $TemplateFactory = $Manager->get('VCTemplateFactory');
        $Templates = $TemplateFactory->query()->getResult();
        foreach ($Templates as $Template) {
            $Template->attach();
        }
        
        /**
         * WP Customizer panel for addons customization
         */
        $Manager->get('AddonsCustomizer')->attach();
    }
    
    static public function languages()
    {
        \load_plugin_textdomain('msp', false, '/msp/languages' );
    }
    
    static public function initVC()
    {
        global $vc_manager;
        if (!isset($vc_manager)) {
            \add_action('admin_notices', array('msp_bootstrap', 'renderNoticeVisualComposerRequired'));
            return;
        }
        
        // To enable Visual Composer page builder for custom post types
        vc_set_default_editor_post_types(array(
            \MSP\DataType\ModelType::MATCH,
            \MSP\DataType\ModelType::PLAYER,
            \MSP\DataType\ModelType::TRAINER,
            \MSP\DataType\ModelType::REFEREE,
            \MSP\DataType\ModelType::TEAM,
            \MSP\DataType\ModelType::CHAMPIONSHIP,
            \MSP\DataType\ModelType::STANDING,
            \MSP\DataType\ModelType::BROADCAST,
            \MSP\DataType\ModelType::VENUE,
            \MSP\DataType\ModelType::COMMENTATOR,
            \MSP\DataType\ModelType::TROPHI,
            'page',
        ));

        // To disable frontend editor 
        \vc_disable_frontend();

        // To remove "Design options", "Custom CSS" tabs.
        \vc_set_as_theme();

        // Shortcodes images sizing
        \add_image_size( 'msp-full-hd', 1920, 1920);
    }
    
    static public function renderNoticeVisualComposerRequired()
    {
        ?>
        <div id="message" class="notice is-dismissible">
            <p><?php esc_html_e('MultiSport Platform: Visual Composer not found, is a required dependency for plugin working.', 'msp'); ?></p>
        </div>
        <?php
    }
    
    /**
     * Extend Layouts Builder system services before setup action in Layouts Bulder.
     */
    static public function extendLayoutBuilder()
    {
        if (!class_exists('\PageComponents\WPObjects\Service\Manager')) {
            return;
        }
        
        $LBManager = \PageComponents\WPObjects\Service\Manager::getInstance();
        $LBManager->addFactory('DepthTypeStorage', function(){
            return new \PageComponents\WPObjects\Data\StorageCombineUnique(array(
                'id' => \PageComponents\DataType\ModelType::DEPTH_TYPE,
                'patches' => array(
                    PAGE_COMPONENTS_PATH . '/data/' . \PageComponents\DataType\ModelType::DEPTH_TYPE .'.php',
                    MSP_PATH . '/data/layout-builder-depth-types-redefine.php'
                ),
            ));
        });
    }
    
}