<?php

/**
 * @param array $filters
 * @param boolean $result_as_object
 * @return \MSP\Model\Match
 */
function team_get_matches($filters, $result_as_object = false)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Factory->query($filters, $result_as_object);
    return $Factory->getResult();
}

function msp__get_match_game_id($match_id = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getGameId();
}

function msp_get_organisation_next_match($organisation_id, $filters = array())
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $next_match = $Factory->query(array_merge($filters, array(
        'numberposts' => -1,
        '_organisation_id' => $organisation_id,
        '_match_status' => 0,
        'orderby' => '_date_start',
        'order' => 'ASC',
        'orderby_type' => 'DATETIME'
    )))->getResult();
    
    if (current($next_match)) {
        return current($next_match);
    }
    
    return null;
}

function team_get_player_data_key($player_id)
{
    return MSP\Model\Match::getPlayerMatchDataKey($player_id);
}

function team_get_player_match_data($match_id, $player_id, $key = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getPlayerData($player_id, $key);
}

/**
 * @param int $match_id
 * @param int $player_id
 * @param array $filters
 * 
 * @return boolean
 * 
 * @deprecated 1.0.0 3.0.11 not usage in MSP
 */
function msp_is_player_compatible_with_match_data($match_id, $player_id, $filters = array())
{
    if (!$filters) {
        return true;
    }
    
    $datas = team_get_player_match_data($match_id, $player_id);
    foreach ($filters as $data_key => $values) {
        $values = msp_param_autocompele_extract($values);
        
        if (!isset($datas[$data_key]) || !is_array($values) || !$values || $values[0] == "") {
            continue;
        }
        
        if ($values[0] == "true") {
            $values[0] = "1";
        }
        
        $current_value = $datas[$data_key];
        if (!in_array($current_value, $values)) {
            return false;
        }
    }
    
    return true;
}

function team_get_team_data_key($organisation_id)
{
    return \MSP\Model\Match::getTeamMatchDataKey($organisation_id);
}

function team_get_team_math_data($match_id, $organisation_id, $key = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTeamData($organisation_id, $key);
}

function msp__get_players_from_match_by_organisation($match_id, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getPlayersByTeam($team_id);
}

function msp__get_players_ids_from_match_by_organisation($match_id, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getPlayersIdsByTeam($team_id);
}

function team_get_players_from_match($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getPlayers();
}

/**
 * Return players from match in primmary staff 
 * grouped by team (left|right) and position key
 * @param int $match_id
 * @return array of arrays
 * @since 1.0.4
 */
function msp__get_players_from_match_group_by_positons($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    return $Factory->get($match_id)->getPlayersGroupByPositions();
}

function msp_get_players_apponents_from_match($match_id)
{
    $players = team_get_players_from_match($match_id);
    $team_left = team_get_match_team($match_id, 0);
    
    $left_players = array();
    $right_players = array();
    foreach ($players as $player) {
        if (team_get_player_match_data($match_id, $player->ID, '_player_team_activity_id') != "primary_staff") {
            continue;
        }
        
        if (team_get_player_match_data($match_id, $player->ID, '_organisation_id') == $team_left->ID) {
            $left_players[] = $player;
        } else {
            $right_players[] = $player;
        }
    }
    
    return array(
        'left' => $left_players, 
        'right' => $right_players, 
        'max' => count($right_players) > count($left_players) ? count($right_players) : count($left_players)
    );
}

function team_get_match_referees($match_id = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getReferees();
}

function team_get_match_trainers_by_team($match_id, $organisation_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTrainersByTeam($organisation_id);
}

function team_get_match_team($match, $number = 0)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match);
    if (!$Match) {
        return null;
    }
    
    return $Match->getTeamByNumber($number);
}

function msp_get_match_organisation_apponent($match_id, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    if (!$Match) {
        return null;
    }
    
    return $Match->getTeamApponent($team_id);
}

function msp__get_match_teams($match)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match);
    return $Match->getTeams();
}

function team_get_match_champ($match)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match);
    return $Match->getChampionship();
}

function team_get_match_scores($match, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match);
    return $Match->getTeamData($team_id);
}

function team_get_match_score($match, $team_id, $key = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match);
    return $Match->getTeamData($team_id, $key);
}

/**
 * @param int $match_id
 * @return int 0 - expected, 1 - live, 2 - finished, 3 - tbd, 4 - postponned, 5 - canceled
 */
function team_get_match_status($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getStatus();
}

function msp__get_match_status_name($match_id = null)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getStatusName();
}

function team_get_match_statuses_checkbox()
{
    return \MSP\Model\Match::getStatusesForCheckbox();
}

function team_get_match_sort_select()
{
    return \MSP\Model\Match::getSortingTypes();
}

function msp__get_match_time_length($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTimeLength();
}

/**
 * @param int identety of match
 * @param string time format
 * @return string with time
 */
function team_get_match_start($match_id, $format = 'j F Y / G:i T')
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTimeStartFormat($format);
}

function team_get_match_start_time_js($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTimeStartJSFormat();
}

function team_get_match_start_time($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTimeStart();
}

function msp__get_player_match_organisation($match_id, $player_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getPlayerTeam($player_id);
}

function team_is_match_player_win($match_id, $player_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->isPlayerWinner($player_id);
}

function msp_is_match_organisation_win($match_id, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->isTeamWinner($team_id);
}

function msp_get_match_broadcasts_ids($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getBroadcastsIds();
}

function msp_get_match_broadcast($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    $BroadCasts = $Match->getBroadcasts();
    return current($BroadCasts) ? current($BroadCasts) : null;
}

function msp__get_match_broadcasts($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getBroadcasts();
}

function msp_get_match_weather($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getWeather();
}

function msp__get_match_team_main_score($match_id, $team_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getTeamMainScore($team_id);
}

function msp__get_match_live_update_time($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->getLiveTimeUpdate();
}

function msp__is_match_live_updated($match_id)
{
    $Factory = \MSP\WPObjects\Service\Manager::getInstance()->get('MatchFactory');
    $Match = $Factory->get($match_id);
    return $Match->isLiveUpdated();
}

