<?php

function msp__get_player_roles_by_ids($roles_ids, $game_id = null)
{
    $result = array();
    foreach ($roles_ids as $roles_id) {
        $role = msp__get_player_roles_by_id($roles_id, $game_id);
        if ($role) {
            $result[] = $role;
        }
    }
    
    return $result;
}

function msp__get_player_roles_by_id($role_id, $game_id = null)
{
    $roles = msp__get_player_roles($game_id);
    foreach ($roles as $role) {
        if ((string)$role->id === $role_id) {
            return $role;
        }
    }
    
    return false;
}

function msp__get_player_roles($game_id = null)
{
    $RoleFactory = \MSP\WPObjects\Service\Manager::getInstance()->get('PlayerRoleFactory');
    $game_qualifier = $RoleFactory->getModelType()->getQualifierAttrName(\MSP\DataType\ModelType::GAME);
    
    if ($game_id) {
        $params = array();
        $params[$game_qualifier] = $game_id;
        $RoleFactory->query($params);
    } else {
        $RoleFactory->query();
    }
    
    return $RoleFactory->getResult();
}

function msp__get_player_position_by_ids($position_ids, $game_id = null)
{
    $result = array();
    foreach ($position_ids as $positions_id) {
        $position = msp__get_player_position_by_id($positions_id, $game_id);
        if ($position) {
            $result[] = $position;
        }
    }
    
    return $result;
}

function msp__get_player_position_by_id($position_id, $game_id)
{
    $positions = msp__get_player_positions($game_id);
    foreach ($positions as $pos) {
        if ((string)$pos->id === $position_id) {
            return $pos;
        }
    }
    
    return false;
}

function msp__get_player_positions($game_id = null)
{
    if (is_null($game_id)) {
        $PositionFactory = \MSP\WPObjects\Service\Manager::getInstance()->get('PlayerPositionFactory');
        $PositionFactory->query();
        return $PositionFactory->getResult();
    }
    
    $GameFactory = \MSP\WPObjects\Service\Manager::getInstance()->get('GameFactory');
    $Game = $GameFactory->get($game_id);
    if (!$Game) {
        return array();
    }
    
    return $Game->getPlayerPositions();
}

function msp_get_player_positions_for_autocomplete()
{
    $positions = msp__get_player_positions();
    
    $result = array();
    foreach ($positions as $position) {
        $result[] = array(
            'label' => $position->name,
            'value' => $position->id,
            'group' => $position->game_id
        );
    }
    
    return $result;
}

function msp_get_player_roles_for_autocomplete()
{
    $roles = msp__get_player_roles();
    
    $result = array();
    foreach ($roles as $role) {
        $result[] = array(
            'label' => $role->name,
            'value' => $role->id,
            'group' => $role->game_id
        );
    }
    
    return $result;
}

function msp_get_player_activity_for_autocomplete()
{
    $types = team_get_player_activity();
    
    $result = array();
    foreach ($types as $type) {
        $result[] = array(
            'label' => (string)$type->name,
            'value' => (string)$type->id
        );
    }
    
    return $result;
}

function team_get_match_event_types($id = null)
{
    $data_source = (include MSP_PATH . 'data/match-event-types.php');
    $data_array = apply_filters('team_get_match_event_types', $data_source);
    $data = array();
    foreach ($data_array as $type) {
        $data[] = new ArrayObject($type, ArrayObject::ARRAY_AS_PROPS);
    }
    
    if (!$id) {
        return $data;
    }
    
    foreach ($data as $type) {
        if ($type->id == $id) {
            return $type;
        }
    }
    
    return false;
}

function msp_param_autocompele_extract($string)
{
    if (is_array($string)) {
        return $string;
    }
    
    $values = explode(', ', $string);
    if (is_array($values) && count($values) !== 0) {
        return $values;
    }
    
    return array();
}

