(function($, ProgressBar, echarts, configs, _, colors){
    
    $('.player-hockey-wrap .circle-item').each(function(index, element){
        
        var $element = $(element);
        var width = $element.attr('data-width');
        var id = $element.find('.circle-bar').first().attr('id');
        
        var circle = new ProgressBar.Circle('#' + id, {
            color: colors['progressbar-text-color'],
            strokeWidth: 4,
            duration: 5000,
            easing: 'easeInOut',
            from: { color: colors['contrast-color'], width: 1 },
                    to: { color: colors['contrast-alt-color'], width: 6 },
                    step: function(state, circle1, attachment) {
                    circle1.path.setAttribute('stroke', state.color);
                    var value = Math.round(circle1.value() * 100);
                        if (value === 0) {
                          circle1.setText('');
                        } else {
                          circle1.setText(value + "%");
                        }
                }
        });

        circle.animate(width / 100);
    });
    
    
    
    
    $(window).on('load', function(){
        
        if (configs === undefined) {
            return;
        }
        
        _.each(configs, function(config){
            
        var $element = $('#' + config.target);
        $element.height($element.width());
            
            
        var chartliexample1 = echarts.init(document.getElementById(config.target));

           var option = {
                tooltip: {
                    trigger: 'item',
                    backgroundColor: 'rgba(0, 0, 0, 0.86)',
                    padding: 10,
                    position : function(p) {
                        return [0, 30];
                    },
                    textStyle : {
                        decoration: 'none',
                        fontFamily: 'Montserrat, sans-serif',
                        fontSize: 14,
                        fontWeight: 'bold'
                    }
                },
                animation: true,
                //animationDuration: 3000,
                animationEasing: 'BounceInOut',
                addDataAnimation: true,
                color: [colors['contrast-color']],
                polar: [
                {
                    indicator: config.labels,
                    splitNumber: 2,
                    shape: 'circle',
                    radius: 80,
                    name: {
                        textStyle: {
                            color: colors['muted-color'],
                            fontFamily: 'Montserrat, sans-serif'
                        }
                    },
                    axisLine: {
                        lineStyle: {
                            color: "#eaeaea",
                            width: 1,
                        }
                    },
                    splitArea: {
                        show: true,
                        areaStyle: {
                            color: "#fcfcfc"
                        }
                    },
                    splitLine: {
                        lineStyle: {
                            color: "#eaeaea",
                            width: 1
                        }
                    }
                }
               ],
                calculable: true,
                series: [
                    {
                        name: config.label,
                        symbol: 'none',
                        type: 'radar',
                        itemStyle: {
                            symbolSize:0,
                            normal: {
                                areaStyle: {
                                    opacity: 1,
                                    type: 'default',
                                    borderWidth: 0
                                }
                            }
                        },
                        data: [
                            {
                                value: config.data,
                                name: config.label
                            }
                        ]
                    }
                ]
           };


           chartliexample1.setOption(option);

       });
        
    });
    
    
})(jQuery, ProgressBar, echarts, msp_player_header_radar, _, msp_player_header);


