<?php

/**
 * @encoding     UTF-8
 * @package      WPObjects
 * @link         https://github.com/VladislavDolgolenko/WPObjects
 * @copyright    Copyright (C) 2018 Vladislav Dolgolenko
 * @license      MIT License
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace MSP\WPObjects\PostType;

use MSP\WPObjects\View\View;

abstract class MetaBox extends View implements
    \MSP\WPObjects\PostType\PostTypeFactoryInterface
{
    protected $id = null;
    protected $title = null;
    protected $position = null;
    protected $priotity = null;
    
    /**
     * @var \MSP\WPObjects\PostType\PostTypeFactory
     */
    protected $PostTypeFactory = null;
    
    /**
     * @var \WP_Post
     */
    protected $Post = null;
    
    protected $box = null;
    
    /**
     * @var \MSP\WPObjects\Model\AbstractPostModel
     */
    protected $PostModel = null;
    
    /**
     * @return array
     */
    abstract public function processing(\MSP\WPObjects\Model\AbstractPostModel $Post, $data);
    
    /**
     * @param \WP_Post $post
     * @return $this
     */
    public function handler(\WP_Post $post, $box)
    {
        $this->Post = $post;
        $this->box = $box;
        
        $this->render();
    }
    
    /**
     * @return \MSP\WPObjects\Model\AbstractPostModel
     */
    protected function getPostModel()
    {
        if (is_null($this->PostModel) && $this->getPost()) {
            $PostType = $this->getPostType();
            $this->PostModel = $PostType->createModel($this->getPost());
        }
        
        return $this->PostModel;
    }
    
    /**
     * @return \MSP\WPObjects\PostType\PostType
     */
    protected function getPostType()
    {
        $Factory = $this->getPostTypeFactory();
        return $Factory->get($this->getPost()->post_type);
    }

    public function getPost()
    {
        return $this->Post;
    }
    
    public function getBox()
    {
        return $this->box;
    }
    
    public function setId($int)
    {
        $this->id = $int;
        
        return $this;
    }
    
    public function getId()
    {
        return $this->id;
    }
    
    public function getName()
    {
        return $this->getTitle();
    }
    
    public function setTitle($string)
    {
        $this->title = $string;
        
        return $this;
    }
    
    public function getTitle()
    {
        return $this->title;
    }
    
    public function setPosition($string)
    {
        $this->position = $string;
        
        return $this;
    }
    
    public function getPosition()
    {
        return $this->position;
    }
    
    public function setPriority($string)
    {
        $this->priotity = $string;
        
        return $this;
    }
    
    public function getPriority()
    {
        return $this->priotity;
    }
    
    /**
     * @return \MSP\WPObjects\PostType\PostTypeFactory
     */
    public function getPostTypeFactory()
    {
        return $this->PostTypeFactory;
    }
    
    /**
     * @param \MSP\WPObjects\PostType\PostTypeFactory $PostTypeFactory
     * @return $this
     */
    public function setPostTypeFactory(\MSP\WPObjects\PostType\PostTypeFactory $PostTypeFactory)
    {
        $this->PostTypeFactory = $PostTypeFactory;
        
        return $this;
    }
    
}

