<?php

/**
 * @encoding     UTF-8
 * @package      WPObjects
 * @link         https://github.com/VladislavDolgolenko/WPObjects
 * @copyright    Copyright (C) 2018 Vladislav Dolgolenko
 * @license      MIT License
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

return array(
    
    /**
     * System namespace
     * inject via DI interface MSP\WPObjects\Service\NamespaceInterface 
     */
    'namespace' => 'WPObjects',
    'build' => '1.0.0',
    'plugin_dir_path' => '',
    'plugin_dir_url' => '',
    'vc_addons_dir_path' => '',
    'vc_templates_dir_path' => '',
    
    'google_api_key' => function($sm){
        return $sm->get('SettingsFactory')->getValue('google_api_key');
    },
    
    /**
     * Dependence Injection Service
     * Configuration DI rules in service.di.php
     */
    'DI' => function ($sm) {
        $DI = new \MSP\WPObjects\Service\DI();
        $DI->addConfig( include $sm->get('wpobjects_dir_path') . '/config/service.di.php');
        return $DI;
    },
            
    /**
     * UserSession
     */
    'SessionStorage' => '\MSP\WPObjects\Session\Storage',
    'Cookies' => '\MSP\WPObjects\Session\Cookies',
            
    /**
     * Data Access Object
     */
    'DataAccess' => '\MSP\WPObjects\Data\Data',
            
    /**
     * Factory query filters listeners
     */
    'WordpressContextFilter' => '\MSP\WPObjects\Factory\FilterHendler\WordPressContext',
    'AggregatorFilter' => '\MSP\WPObjects\Factory\FilterHendler\Agregators',
            
    /**
     * Data storages
     */
    'PostTypeStorage' => function ($sm) {
        $data = new \MSP\WPObjects\Data\StorageCombine(array(
            'id' => 'post-type',
            'patches' => array(
                $sm->get('wpobjects_dir_path') . '/storage/post-types.php'
            )
        ));
        
        return $data;
    },
            
    'DataTypeStorage' => function ($sm) {
        return new \MSP\WPObjects\Data\Storage(array(
            'id' => 'datas',
            'include' => $sm->get('wpobjects_dir_path') . '/storage/data.php'
        ));
    },
            
    'SettingsStorage' => function ($sm) {
        return new MSP\WPObjects\Data\Storage(array(
            'id' => 'settings',
            'include' => $sm->get('wpobjects_dir_path') . '/storage/settings.php'
        ));
    },
    
);